@@ -194,7 +194,14 @@ enum {
 	ESLURM_RESERVATION_EMPTY =			2080,
 	ESLURM_INVALID_ARRAY,
 	ESLURM_RESERVATION_NAME_DUP,
+	ESLURM_JOB_STARTED,
+	ESLURM_JOB_FINISHED,
+	ESLURM_JOB_NOT_RUNNING,
+	ESLURM_JOB_NOT_PENDING_NOR_RUNNING,
+	ESLURM_JOB_NOT_SUSPENDED,
+	ESLURM_JOB_NOT_FINISHED,
 	ESLURM_TRIGGER_DUP,
+	ESLURM_INTERNAL =				2090,
 
 	/* switch specific error codes, specific values defined in plugin module */
 	ESLURM_SWITCH_MIN = 3000,
