@@ -48,6 +48,8 @@
 
 #include "slurm/slurm.h"
 
+#include "src/common/cpu_frequency.h"
+#include "src/common/list.h"
 #include "src/common/parse_time.h"
 #include "src/common/read_config.h"
 #include "src/common/slurm_auth.h"
@@ -56,7 +58,10 @@
 #include "src/common/slurm_selecttype_info.h"
 #include "src/common/xmalloc.h"
 #include "src/common/xstring.h"
-#include "src/common/list.h"
+
+/* Local functions */
+static void _write_group_header(FILE* out, char * header);
+static void _write_key_pairs(FILE* out, void *key_pairs);
 
 /*
  * slurm_api_version - Return a single number reflecting the SLURM API's
@@ -92,9 +97,188 @@ _reset_period_str(uint16_t reset_period)
 	}
 }
 
+/*
+ * slurm_write_ctl_conf - write the contents of slurm control configuration
+ * IN slurm_ctl_conf_ptr - slurm control configuration pointer
+ * IN node_info_ptr - pointer to node table of information
+ * IN part_info_ptr - pointer to partition information
+ */
+void slurm_write_ctl_conf ( slurm_ctl_conf_info_msg_t * slurm_ctl_conf_ptr,
+			    node_info_msg_t * node_info_ptr,
+			    partition_info_msg_t * part_info_ptr)
+{
+	int i = 0;
+	char time_str[32];
+	char *tmp_str = NULL;
+	char *base_path = NULL;
+	char *path = NULL;
+	void *ret_list = NULL;
+	FILE *fp = NULL;
+	partition_info_t *part_ptr = NULL;
+	struct records {
+	  char *rec;
+	  hostlist_t hostlist;
+	  struct records *next;
+	} *rp = NULL;
+	struct records *crp;
+
+	if ( slurm_ctl_conf_ptr == NULL )
+		return ;
+
+	slurm_make_time_str ((time_t *)&slurm_ctl_conf_ptr->last_update,
+			     time_str, sizeof(time_str));
+
+	/* open new slurm.conf.<datetime> file for write. This file will
+	 * contain the currently running slurm configuration. */
+
+	base_path = getenv("SLURM_CONF");
+	if (base_path == NULL)
+		base_path = default_slurm_config_file;
+
+	xstrfmtcat (path, "%s.%s", base_path, time_str);
+
+	debug("Writing slurm.conf file: %s", path);
+
+	if ( ( fp = fopen(path, "w") ) == NULL ) {
+		fprintf(stderr, "Could not create file %s: %s\n", path, 
+			strerror(errno));
+		xfree(path);
+		return;
+	}
+
+	fprintf(fp,
+		"########################################################\n");
+	fprintf(fp,
+		"#  Configuration file for SLURM - %s  #\n", time_str);
+	fprintf(fp,
+		"########################################################\n");
+	fprintf(fp, "#\n#\n");
+
+	ret_list = slurm_ctl_conf_2_key_pairs(slurm_ctl_conf_ptr);
+	if (ret_list) {
+		_write_key_pairs(fp, ret_list);
+		list_destroy((List)ret_list);
+	}
+
+	_write_group_header (fp, "NODES");
+	/* Write node info; first create a string (tmp_str) that contains
+	 * all fields associated with a node (but do not include the node
+	 * name itself). Search for duplicate tmp_str records as we process
+	 * each node entry so not to have duplicates. Associate each node
+	 * name that has equal tmp_str records and create a hostlist_t string
+	 * for that record. */
+	for (i = 0; i < node_info_ptr->record_count; i++) {
+		if (node_info_ptr->node_array[i].name == NULL)
+			continue;
+
+		if (node_info_ptr->node_array[i].node_hostname != NULL &&
+		   strcmp(node_info_ptr->node_array[i].node_hostname,
+			  node_info_ptr->node_array[i].name))
+			xstrfmtcat(tmp_str, " NodeHostName=%s",
+				   node_info_ptr->node_array[i].node_hostname);
+
+		if (node_info_ptr->node_array[i].node_addr != NULL &&
+		   strcmp(node_info_ptr->node_array[i].node_addr,
+			  node_info_ptr->node_array[i].name))
+		                xstrfmtcat(tmp_str, " NodeAddr=%s",
+				   node_info_ptr->node_array[i].node_addr);
+
+		if (node_info_ptr->node_array[i].sockets)
+		        xstrfmtcat(tmp_str, " Sockets=%u",
+				   node_info_ptr->node_array[i].sockets);
+
+		if (node_info_ptr->node_array[i].cores)
+		        xstrfmtcat(tmp_str,  " CoresPerSocket=%u",
+				   node_info_ptr->node_array[i].cores);
+
+		if (node_info_ptr->node_array[i].threads)
+		        xstrfmtcat(tmp_str, " ThreadsPerCore=%u",
+				   node_info_ptr->node_array[i].threads);
+
+		if (node_info_ptr->node_array[i].gres != NULL)
+		        xstrfmtcat(tmp_str, " Gres=%s",
+				   node_info_ptr->node_array[i].gres);
+
+		if (node_info_ptr->node_array[i].real_memory > 1)
+		        xstrfmtcat(tmp_str, " RealMemory=%u",
+				   node_info_ptr->node_array[i].real_memory);
+
+		if (node_info_ptr->node_array[i].tmp_disk)
+		        xstrfmtcat(tmp_str, " TmpDisk=%u",
+				   node_info_ptr->node_array[i].tmp_disk);
+
+		if (node_info_ptr->node_array[i].weight != -1)
+		        xstrfmtcat(tmp_str, " Weight=%u",
+				   node_info_ptr->node_array[i].weight);
+
+		if (node_info_ptr->node_array[i].features != NULL)
+		        xstrfmtcat(tmp_str, " Feature=%s",
+				   node_info_ptr->node_array[i].features);
+
+		/* check for duplicate records */
+		for (crp = rp; crp != NULL; crp = crp->next) {
+			if (!strcmp(crp->rec, tmp_str)) {
+				xfree(tmp_str);
+				break;
+			}
+		}
+		if (crp == NULL) {
+			crp = xmalloc(sizeof(struct records));
+			crp->rec = tmp_str;
+			tmp_str = NULL;	/* transfered to record */
+			crp->hostlist = hostlist_create("");
+			hostlist_push(crp->hostlist,
+				      node_info_ptr->node_array[i].name);
+			crp->next = rp;
+			rp = crp;
+		} else {
+			hostlist_push(crp->hostlist,
+				      node_info_ptr->node_array[i].name);
+		}
+	}
+
+	/* now write the node strings to the output file */
+	for (crp = rp; crp != NULL; crp = crp->next) {
+		tmp_str = hostlist_ranged_string_xmalloc(crp->hostlist);
+		fprintf(fp, "NodeName=%s%s\n", tmp_str, crp->rec);
+		debug("Hostlist: %s written to output file.", tmp_str);
+		xfree(tmp_str);
+		xfree(crp->rec);
+		hostlist_destroy(crp->hostlist);
+	}
+	/* free structure elements */
+	while (rp != NULL) {
+		crp = rp;
+		rp = rp->next;
+		xfree(crp);
+	}
+
+	_write_group_header (fp, "PARTITIONS");
+	/* now write partition info */
+	part_ptr = part_info_ptr->partition_array;
+	for (i = 0; i < part_info_ptr->record_count; i++) {
+		if (part_ptr[i].name == NULL)
+			continue;
+		fprintf(fp, "PartitionName=%s", part_ptr[i].name);
+		if (part_ptr[i].nodes != NULL)
+			fprintf(fp, " Nodes=%s", part_ptr[i].nodes);
+		if (part_ptr[i].max_time != INFINITE)
+			fprintf(fp, " MaxTime=%u", part_ptr[i].max_time);
+		if (part_ptr[i].flags & PART_FLAG_DEFAULT)
+			fprintf(fp, " DEFAULT=YES");
+
+		fprintf(fp, "\n");
+	}
+
+	fprintf(stdout, "Slurm config saved to %s\n", path);
+
+	xfree(path);
+	fclose(fp);
+}
+
 /*
  * slurm_print_ctl_conf - output the contents of slurm control configuration
- *	message as loaded using slurm_load_ctl_conf
+ *	message as loaded using slurm_load_ctl_conf()
  * IN out - file to write to
  * IN slurm_ctl_conf_ptr - slurm control configuration pointer
  */
@@ -126,7 +310,6 @@ void slurm_print_ctl_conf ( FILE* out,
 	ret_list = slurm_ctl_conf_2_key_pairs(slurm_ctl_conf_ptr);
 	if (ret_list) {
 		slurm_print_key_pairs(out, ret_list, tmp_str);
-
 		list_destroy((List)ret_list);
 	}
 
@@ -231,6 +414,13 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->acct_gather_profile_type);
 	list_append(ret_list, key_pair);
 
+	snprintf(tmp_str, sizeof(tmp_str), "%u",
+		 slurm_ctl_conf_ptr->use_spec_resources);
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("AllowSpecResourcesUsage");
+	key_pair->value = xstrdup(tmp_str);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("AuthInfo");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->authinfo);
@@ -278,6 +468,11 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->checkpoint_type);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("ChosLoc");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->chos_loc);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("ClusterName");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->cluster_name);
@@ -305,6 +500,13 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->core_spec_plugin);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("CpuFreqDef");
+	cpu_freq_to_string(tmp_str, sizeof(tmp_str),
+			   slurm_ctl_conf_ptr->cpu_freq_def);
+	key_pair->value = xstrdup(tmp_str);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("CryptoType");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->crypto_type);
@@ -317,7 +519,10 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	list_append(ret_list, key_pair);
-	if (slurm_ctl_conf_ptr->def_mem_per_cpu & MEM_PER_CPU) {
+	if (slurm_ctl_conf_ptr->def_mem_per_cpu == INFINITE) {
+		key_pair->name = xstrdup("DefMemPerNode");
+		key_pair->value = xstrdup("UNLIMITED");
+	} else if (slurm_ctl_conf_ptr->def_mem_per_cpu & MEM_PER_CPU) {
 		key_pair->name = xstrdup("DefMemPerCPU");
 		snprintf(tmp_str, sizeof(tmp_str), "%u",
 			 slurm_ctl_conf_ptr->def_mem_per_cpu &
@@ -596,6 +801,11 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->launch_type);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("Layouts");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->layouts);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("Licenses");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->licenses);
@@ -634,7 +844,10 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	list_append(ret_list, key_pair);
-	if (slurm_ctl_conf_ptr->max_mem_per_cpu & MEM_PER_CPU) {
+	if (slurm_ctl_conf_ptr->max_mem_per_cpu == INFINITE) {
+		key_pair->name = xstrdup("MaxMemPerNode");
+		key_pair->value = xstrdup("UNLIMITED");
+	} else if (slurm_ctl_conf_ptr->max_mem_per_cpu & MEM_PER_CPU) {
 		key_pair->name = xstrdup("MaxMemPerCPU");
 		snprintf(tmp_str, sizeof(tmp_str), "%u",
 			 slurm_ctl_conf_ptr->max_mem_per_cpu & (~MEM_PER_CPU));
@@ -664,6 +877,14 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(tmp_str);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("MemLimitEnforce");
+	if (slurm_ctl_conf_ptr->mem_limit_enforce)
+		key_pair->value = xstrdup("yes");
+	else
+		key_pair->value = xstrdup("no");
+	list_append(ret_list, key_pair);
+
 	snprintf(tmp_str, sizeof(tmp_str), "%u sec",
 		 slurm_ctl_conf_ptr->msg_timeout);
 	key_pair = xmalloc(sizeof(config_key_pair_t));
@@ -733,6 +954,11 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->preempt_type);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("PriorityParameters");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->priority_params);
+	list_append(ret_list, key_pair);
+
 	if (strcmp(slurm_ctl_conf_ptr->priority_type, "priority/basic") == 0) {
 		key_pair = xmalloc(sizeof(config_key_pair_t));
 		key_pair->name = xstrdup("PriorityType");
@@ -760,11 +986,10 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 		key_pair->value = xstrdup(tmp_str);
 		list_append(ret_list, key_pair);
 
-		snprintf(tmp_str, sizeof(tmp_str), "%u",
-			 slurm_ctl_conf_ptr->priority_flags);
 		key_pair = xmalloc(sizeof(config_key_pair_t));
 		key_pair->name = xstrdup("PriorityFlags");
-		key_pair->value = xstrdup(tmp_str);
+		key_pair->value = priority_flags_string(slurm_ctl_conf_ptr->
+							priority_flags);
 		list_append(ret_list, key_pair);
 
 		secs2time_str((time_t) slurm_ctl_conf_ptr->priority_max_age,
@@ -879,6 +1104,16 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 		reconfig_flags2str(slurm_ctl_conf_ptr->reconfig_flags);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("RequeueExit");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->requeue_exit);
+	list_append(ret_list, key_pair);
+
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("RequeueExitHold");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->requeue_exit_hold);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("ResumeProgram");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->resume_program);
@@ -925,6 +1160,11 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(tmp_str);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("RoutePlugin");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->route_plugin);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("SallocDefaultCommand");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->salloc_default_command);
@@ -995,11 +1235,6 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->slurmctld_logfile);
 	list_append(ret_list, key_pair);
 
-	key_pair = xmalloc(sizeof(config_key_pair_t));
-	key_pair->name = xstrdup("SlurmSchedLogFile");
-	key_pair->value = xstrdup(slurm_ctl_conf_ptr->sched_logfile);
-	list_append(ret_list, key_pair);
-
 	if (slurm_ctl_conf_ptr->slurmctld_port_count > 1) {
 		uint32_t high_port = slurm_ctl_conf_ptr->slurmctld_port;
 		high_port += (slurm_ctl_conf_ptr->slurmctld_port_count - 1);
@@ -1072,6 +1307,11 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(tmp_str);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("SlurmSchedLogFile");
+	key_pair->value = xstrdup(slurm_ctl_conf_ptr->sched_logfile);
+	list_append(ret_list, key_pair);
+
 	snprintf(tmp_str, sizeof(tmp_str), "%u",
 		 slurm_ctl_conf_ptr->sched_log_level);
 	key_pair = xmalloc(sizeof(config_key_pair_t));
@@ -1104,6 +1344,17 @@ extern void *slurm_ctl_conf_2_key_pairs (slurm_ctl_conf_t* slurm_ctl_conf_ptr)
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->srun_epilog);
 	list_append(ret_list, key_pair);
 
+	key_pair = xmalloc(sizeof(config_key_pair_t));
+	key_pair->name = xstrdup("SrunPortRange");
+	key_pair->value = xstrdup_printf("%u-%u",
+			(slurm_ctl_conf_ptr->srun_port_range &&
+			 slurm_ctl_conf_ptr->srun_port_range[0] != 0) ?
+				slurm_ctl_conf_ptr->srun_port_range[0] : 0,
+			(slurm_ctl_conf_ptr->srun_port_range &&
+			 slurm_ctl_conf_ptr->srun_port_range[1] != 0) ?
+				slurm_ctl_conf_ptr->srun_port_range[1] : 0);
+	list_append(ret_list, key_pair);
+
 	key_pair = xmalloc(sizeof(config_key_pair_t));
 	key_pair->name = xstrdup("SrunProlog");
 	key_pair->value = xstrdup(slurm_ctl_conf_ptr->srun_prolog);
@@ -1417,6 +1668,295 @@ void slurm_print_slurmd_status (FILE* out,
 	return;
 }
 
+/*
+ * _write_key_pairs - write the contents of slurm
+ *	configuration to an output file
+ * IN out - file to write to
+ * IN key_pairs - key pairs of the running slurm configuration
+ */
+static void _write_key_pairs(FILE* out, void *key_pairs)
+{
+	config_key_pair_t *key_pair;
+	char *temp = NULL;
+	List config_list = (List)key_pairs;
+	ListIterator iter = NULL;
+	/* define lists of specific configuration sections */
+	List other_list = list_create(slurm_destroy_char);
+	List control_list = list_create(slurm_destroy_char);
+	List accounting_list = list_create(slurm_destroy_char);
+	List logging_list = list_create(slurm_destroy_char);
+	List power_list = list_create(slurm_destroy_char);
+	List sched_list = list_create(slurm_destroy_char);
+	List topology_list = list_create(slurm_destroy_char);
+	List timers_list = list_create(slurm_destroy_char);
+	List debug_list = list_create(slurm_destroy_char);
+	List proepilog_list = list_create(slurm_destroy_char);
+	List resconf_list = list_create(slurm_destroy_char);
+	List proctrac_list = list_create(slurm_destroy_char);
+
+	if (!config_list)
+		return;
+
+	iter = list_iterator_create(config_list);
+	while ((key_pair = list_next(iter))) {
+		/* Ignore ENV variables in config_list; they'll
+		 * cause problems in an active slurm.conf */
+		if (!strcmp(key_pair->name, "BOOT_TIME") ||
+		    !strcmp(key_pair->name, "HASH_VAL") ||
+		    !strcmp(key_pair->name, "NEXT_JOB_ID") ||
+		    !strcmp(key_pair->name, "SLURM_CONF") ||
+		    !strcmp(key_pair->name, "SLURM_VERSION")) {
+			debug("Ignoring %s (not written)", key_pair->name);
+			continue;
+		}
+
+		/* Certain values need to be changed to prevent
+		 * errors in reading/parsing the conf file */
+		if (!strcasecmp(key_pair->name, "SuspendTime") &&
+		    !strcasecmp(key_pair->value, "NONE"))
+			strcpy(key_pair->value, "0");
+
+		/* Comment out certain key_pairs */
+		/* - TaskPluginParam=(null type) is not a NULL but
+		 * it does imply no value */
+		if ((key_pair->value == NULL) ||
+		    (strlen(key_pair->value) == 0) ||
+		    !strcasecmp(key_pair->value, "(null type)") ||
+		    !strcasecmp(key_pair->value, "N/A") ||
+		    (!strcasecmp(key_pair->name, "KeepAliveTime") &&
+		     !strcasecmp(key_pair->value, "SYSTEM_DEFAULT")) ||
+		    !strcasecmp(key_pair->name, "DynAllocPort") ||
+		    (!strcasecmp(key_pair->name, "DefMemPerNode") &&
+		     !strcasecmp(key_pair->value, "UNLIMITED"))) {
+			temp = xstrdup_printf("#%s=", key_pair->name);
+			debug("Commenting out %s=%s",
+			      key_pair->name,
+			      key_pair->value);
+		} else {
+			key_pair->value = strtok(key_pair->value, " (");
+			temp = xstrdup_printf("%s=%s",
+					      key_pair->name, key_pair->value);
+		}
+
+		if (!strcasecmp(key_pair->name, "ControlMachine") ||
+		    !strcasecmp(key_pair->name, "ControlAddr") ||
+		    !strcasecmp(key_pair->name, "ClusterName") ||
+		    !strcasecmp(key_pair->name, "SlurmUser") ||
+		    !strcasecmp(key_pair->name, "SlurmdUser") ||
+		    !strcasecmp(key_pair->name, "SlurmctldPort") ||
+		    !strcasecmp(key_pair->name, "SlurmdPort") ||
+		    !strcasecmp(key_pair->name, "BackupAddr") ||
+		    !strcasecmp(key_pair->name, "BackupController")) {
+			list_append(control_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "StateSaveLocation") ||
+		    !strcasecmp(key_pair->name, "SlurmdSpoolDir") ||
+		    !strcasecmp(key_pair->name, "SlurmctldLogFile") ||
+		    !strcasecmp(key_pair->name, "SlurmdLogFile") ||
+		    !strcasecmp(key_pair->name, "SlurmctldPidFile") ||
+		    !strcasecmp(key_pair->name, "SlurmdPidFile") ||
+		    !strcasecmp(key_pair->name, "SlurmSchedLogFile") ||
+		    !strcasecmp(key_pair->name, "SlurmEventHandlerLogfile")) {
+			list_append(logging_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "AccountingStorageBackupHost") ||
+		    !strcasecmp(key_pair->name, "AccountingStorageEnforce") ||
+		    !strcasecmp(key_pair->name, "AccountingStorageHost") ||
+		    !strcasecmp(key_pair->name, "AccountingStorageLoc") ||
+		    !strcasecmp(key_pair->name, "AccountingStoragePort") ||
+		    !strcasecmp(key_pair->name, "AccountingStorageType") ||
+		    !strcasecmp(key_pair->name, "AccountingStorageUser") ||
+		    !strcasecmp(key_pair->name, "AccountingStoreJobComment") ||
+		    !strcasecmp(key_pair->name, "AcctGatherEnergyType") ||
+		    !strcasecmp(key_pair->name, "AcctGatherFilesystemType") ||
+		    !strcasecmp(key_pair->name, "AcctGatherInfinibandType") ||
+		    !strcasecmp(key_pair->name, "AcctGatherNodeFreq") ||
+		    !strcasecmp(key_pair->name, "AcctGatherProfileType") ||
+		    !strcasecmp(key_pair->name, "JobAcctGatherFrequency") ||
+		    !strcasecmp(key_pair->name, "JobAcctGatherType") ||
+		    !strcasecmp(key_pair->name, "ExtSensorsType") ||
+		    !strcasecmp(key_pair->name, "ExtSensorsFreq")) {
+			list_append(accounting_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "SuspendExcNodes") ||
+		    !strcasecmp(key_pair->name, "SuspendExcParts") ||
+		    !strcasecmp(key_pair->name, "SuspendProgram") ||
+		    !strcasecmp(key_pair->name, "SuspendRate") ||
+		    !strcasecmp(key_pair->name, "SuspendTime") ||
+		    !strcasecmp(key_pair->name, "SuspendTimeout") ||
+		    !strcasecmp(key_pair->name, "ResumeProgram") ||
+		    !strcasecmp(key_pair->name, "ResumeRate") ||
+		    !strcasecmp(key_pair->name, "ResumeTimeout")) {
+			list_append(power_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "SelectType") ||
+		    !strcasecmp(key_pair->name, "SelectTypeParameters") ||
+		    !strcasecmp(key_pair->name, "SchedulerParameters") ||
+		    !strcasecmp(key_pair->name, "SchedulerPort") ||
+		    !strcasecmp(key_pair->name, "SchedulerRootFilter") ||
+		    !strcasecmp(key_pair->name, "SchedulerTimeSlice") ||
+		    !strcasecmp(key_pair->name, "SchedulerType") ||
+		    !strcasecmp(key_pair->name, "SlurmSchedLogLevel") ||
+		    !strcasecmp(key_pair->name, "PreemptMode") ||
+		    !strcasecmp(key_pair->name, "PreemptType") ||
+		    !strcasecmp(key_pair->name, "PriorityType") ||
+		    !strcasecmp(key_pair->name, "FastSchedule")) {
+			list_append(sched_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "TopologyPlugin")) {
+			list_append(topology_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "SlurmctldTimeout") ||
+		    !strcasecmp(key_pair->name, "SlurmdTimeout") ||
+		    !strcasecmp(key_pair->name, "InactiveLimit") ||
+		    !strcasecmp(key_pair->name, "MinJobAge") ||
+		    !strcasecmp(key_pair->name, "KillWait") ||
+		    !strcasecmp(key_pair->name, "BatchStartTimeout") ||
+		    !strcasecmp(key_pair->name, "CompleteWait") ||
+		    !strcasecmp(key_pair->name, "EpilogMsgTime") ||
+		    !strcasecmp(key_pair->name, "GetEnvTimeout") ||
+		    !strcasecmp(key_pair->name, "Waittime")) {
+			list_append(timers_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "SlurmctldDebug") ||
+		    !strcasecmp(key_pair->name, "SlurmdDebug") ||
+		    !strcasecmp(key_pair->name, "DebugFlags")) {
+			list_append(debug_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "TaskPlugin") ||
+		    !strcasecmp(key_pair->name, "TaskPluginParam")) {
+			list_append(resconf_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "ProcTrackType")) {
+			list_append(proctrac_list, temp);
+			continue;
+		}
+
+		if (!strcasecmp(key_pair->name, "Epilog") ||
+		    !strcasecmp(key_pair->name, "Prolog") ||
+		    !strcasecmp(key_pair->name, "SrunProlog") ||
+		    !strcasecmp(key_pair->name, "SrunEpilog") ||
+		    !strcasecmp(key_pair->name, "TaskEpilog") ||
+		    !strcasecmp(key_pair->name, "TaskProlog")) {
+			list_append(proepilog_list, temp);
+			continue;
+		} else {
+			list_append(other_list, temp);
+		}
+	}
+	list_iterator_destroy(iter);
+
+	_write_group_header (out, "CONTROL");
+	iter = list_iterator_create(control_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)control_list);
+
+	_write_group_header (out, "LOGGING & OTHER PATHS");
+	iter = list_iterator_create(logging_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)logging_list);
+
+	_write_group_header (out, "ACCOUNTING");
+	iter = list_iterator_create(accounting_list);
+	while((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)accounting_list);
+
+	_write_group_header (out, "SCHEDULING & ALLOCATION");
+	iter = list_iterator_create(sched_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)sched_list);
+
+	_write_group_header (out, "TOPOLOGY");
+	iter = list_iterator_create(topology_list);
+	while((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)topology_list);
+
+	_write_group_header (out, "TIMERS");
+	iter = list_iterator_create(timers_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)timers_list);
+
+	_write_group_header (out, "POWER");
+	iter = list_iterator_create(power_list);
+	while((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)power_list);
+
+	_write_group_header (out, "DEBUG");
+	iter = list_iterator_create(debug_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)debug_list);
+
+	_write_group_header (out, "EPILOG & PROLOG");
+	iter = list_iterator_create(proepilog_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)proepilog_list);
+
+	_write_group_header (out, "PROCESS TRACKING");
+	iter = list_iterator_create(proctrac_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)proctrac_list);
+
+	_write_group_header (out, "RESOURCE CONFINEMENT");
+	iter = list_iterator_create(resconf_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)resconf_list);
+
+	_write_group_header (out, "OTHER");
+	iter = list_iterator_create(other_list);
+	while ((temp = list_next(iter)))
+		fprintf(out, "%s\n", temp);
+	list_iterator_destroy(iter);
+	list_destroy((List)other_list);
+
+}
+
+/*
+ * slurm_print_key_pairs - output the contents of key_pairs
+ * which is a list of opaque data type config_key_pair_t
+ * IN out - file to write to
+ * IN key_pairs - List containing key pairs to be printed
+ * IN title - title of key pair list
+ */
 extern void slurm_print_key_pairs(FILE* out, void *key_pairs, char *title)
 {
 	List config_list = (List)key_pairs;
@@ -1428,8 +1968,43 @@ extern void slurm_print_key_pairs(FILE* out, void *key_pairs, char *title)
 
 	fprintf(out, "%s", title);
 	iter = list_iterator_create(config_list);
-	while((key_pair = list_next(iter))) {
+	while ((key_pair = list_next(iter))) {
 		fprintf(out, "%-23s = %s\n", key_pair->name, key_pair->value);
 	}
 	list_iterator_destroy(iter);
 }
+
+/*
+ * _write_group_header - write the group headers on the
+ *	output slurm configuration file - with the header
+ *      string centered between the hash characters
+ * IN out - file to write to
+ * IN header - header string to write
+ */
+static void _write_group_header(FILE* out, char * header)
+{
+	static int comlen = 48;
+	int i, hdrlen, left, right;
+
+	if (!header)
+		return;
+	hdrlen = strlen(header);
+	left = ((comlen - hdrlen) / 2) - 1;
+	right = left;
+	if ((comlen - hdrlen) % 2)
+		right++; 
+
+	fprintf(out, "#\n");
+	for (i = 0; i < comlen; i++)
+		fprintf(out, "#");
+	fprintf(out, "\n#");
+	for (i = 0; i < left; i++)
+		fprintf(out, " ");
+	fprintf(out, "%s", header);
+	for (i = 0; i < right; i++)
+		fprintf(out, " ");
+	fprintf(out, "#\n");
+	for (i = 0; i < comlen; i++)
+		fprintf(out, "#");
+	fprintf(out, "\n");
+}
