@@ -590,16 +590,19 @@ void slurm_step_launch_wait_finish(slurm_step_ctx_t *ctx)
 				sls->abort_action_taken = true;
 			}
 			if (!time_set) {
+				uint16_t kill_wait;
 				/* Only set the time once, because we only want
 				 * to wait STEP_ABORT_TIME, no matter how many
 				 * times the condition variable is signalled.
 				 */
-				ts.tv_sec = time(NULL) + STEP_ABORT_TIME;
+				kill_wait = slurm_get_kill_wait();
+				ts.tv_sec = time(NULL) + STEP_ABORT_TIME
+					+ kill_wait;
 				time_set = true;
 				/* FIXME - should this be a callback? */
 				info("Job step aborted: Waiting up to "
 				     "%d seconds for job step to finish.",
-				     STEP_ABORT_TIME);
+				     kill_wait + STEP_ABORT_TIME);
 			}
 
 			errnum = pthread_cond_timedwait(&sls->cond,
