@@ -66,9 +66,12 @@ typedef struct gres_slurmd_conf {
 	char *file;
 	uint8_t has_file;	/* non-zero if file is set, flag for RPC */
 
-	/* Name of this gres type */
+	/* Name of this gres */
 	char *name;
 
+	/* Type of this gres (e.g. model name) */
+	char *type;
+
 	/* Gres ID number */
 	uint32_t plugin_id;
 } gres_slurmd_conf_t;
@@ -81,29 +84,44 @@ typedef struct gres_node_state {
 	/* Configured resources via Gres parameter */
 	uint32_t gres_cnt_config;
 
+	/* Non-consumable: Do not track resources allocated to jobs */
+	bool no_consume;
+
 	/* Total resources available for allocation to jobs.
 	 * gres_cnt_found or gres_cnt_config, depending upon FastSchedule */
 	uint32_t gres_cnt_avail;
 
+	/* List of GRES in current use. Set NULL if needs to be rebuilt. */
+	char *gres_used;
+
 	/* Resources currently allocated to jobs */
 	uint32_t  gres_cnt_alloc;
 	bitstr_t *gres_bit_alloc;	/* If gres.conf contains File field */
 
-	/* Topology specific information (if gres.conf contains CPUs spec) */
-	uint16_t topo_cnt;
+	/* Topology specific information (if gres.conf contains CPUs option) */
+	uint16_t topo_cnt;		/* Size of topo_ arrays */
 	bitstr_t **topo_cpus_bitmap;
 	bitstr_t **topo_gres_bitmap;
 	uint32_t *topo_gres_cnt_alloc;
 	uint32_t *topo_gres_cnt_avail;
+	char **topo_model;		/* Type of this gres (e.g. model name) */
+
+	/* Gres type specific information (if gres.conf contains type option) */
+	uint16_t type_cnt;		/* Size of type_ arrays */
+	uint32_t *type_cnt_alloc;
+	uint32_t *type_cnt_avail;
+	char **type_model;		/* Type of this gres (e.g. model name) */
 } gres_node_state_t;
 
 /* Gres job state as used by slurmctld daemon */
 typedef struct gres_job_state {
+	char *type_model;		/* Type of this gres (e.g. model name) */
+
 	/* Count of resources needed per node */
 	uint32_t gres_cnt_alloc;
 
 	/* Resources currently allocated to job on each node */
-	uint32_t node_cnt;
+	uint32_t node_cnt;		/* 0 if no_consume */
 	bitstr_t **gres_bit_alloc;
 
 	/* Resources currently allocated to job steps on each node.
@@ -115,6 +133,8 @@ typedef struct gres_job_state {
 
 /* Gres job step state as used by slurmctld daemon */
 typedef struct gres_step_state {
+	char *type_model;		/* Type of this gres (e.g. model name) */
+
 	/* Count of resources needed per node */
 	uint32_t gres_cnt_alloc;
 
@@ -314,6 +334,20 @@ extern void gres_plugin_node_state_dealloc_all(List gres_list);
  */
 extern void gres_plugin_node_state_log(List gres_list, char *node_name);
 
+/*
+ * Build a string indicating a node's drained GRES
+ * IN gres_list - generated by gres_plugin_node_config_validate()
+ * RET - string, must be xfreed by caller
+ */
+extern char *gres_get_node_drain(List gres_list);
+
+/*
+ * Build a string indicating a node's used GRES
+ * IN gres_list - generated by gres_plugin_node_config_validate()
+ * RET - string, must be xfreed by caller
+ */
+extern char *gres_get_node_used(List gres_list);
+
 /*
  * Fill in an array of GRES type ids contained within the given node gres_list
  *		and an array of corresponding counts of those GRES types.
