@@ -135,7 +135,7 @@ typedef struct {
 	log_options_t opt;
 	unsigned initialized:1;
 	uint16_t fmt;            /* Flag for specifying timestamp format */
-	uint32_t debug_flags;
+	uint64_t debug_flags;
 }	log_t;
 
 char *slurm_prog_name = NULL;
@@ -568,7 +568,7 @@ int log_alter(log_options_t opt, log_facility_t fac, char *logfile)
  */
 void log_set_debug_flags(void)
 {
-	uint32_t debug_flags = slurm_get_debug_flags();
+	uint64_t debug_flags = slurm_get_debug_flags();
 
 	slurm_mutex_lock(&log_lock);
 	log->debug_flags = debug_flags;
@@ -919,12 +919,13 @@ static void
 _log_printf(log_t *log, cbuf_t cb, FILE *stream, const char *fmt, ...)
 {
 	va_list ap;
-	int fd = fileno(stream);
+	int fd = -1;
 
-	/* If the fd is less than 0 just return sense we can't do
-	   anything here.  This can happen if a calling program is the
-	   one that set up the io.
-	*/
+	/* If the fd is less than 0 just return since we can't do anything here.
+	 * This can happen if a calling program is the one that set up the io.
+	 */
+	if (stream)
+		fd = fileno(stream);
 	if (fd < 0)
 		return;
 
