@@ -184,4 +184,12 @@ extern void bg_figure_nodes_tasks(int *min_nodes, int *max_nodes,
 				  bool nodes_set_opt, bool overcommit,
 				  bool set_tasks);
 
+/*
+ *  _parse_flags  is used to parse the Flags= option.  It handles
+ *  daily, weekly, static_alloc, part_nodes, and maint, optionally
+ *  preceded by + or -, separated by a comma but no spaces.
+ */
+
+extern uint32_t parse_resv_flags(const char *flagstr, const char *msg);
+
 #endif /* !_PROC_ARGS_H */
