@@ -1164,8 +1164,8 @@ void format_core_allocs(slurm_cred_t *cred, char *node_name, uint16_t cpus,
 	else {
 		uint32_t i = cpus / (i_last_bit - i_first_bit);
 		if (i > 1) {
-			info("scaling CPU count by factor of %d (%u/(%u-%u)",
-			     i, cpus, i_last_bit, i_first_bit);
+			debug2("scaling CPU count by factor of %d (%u/(%u-%u)",
+			       i, cpus, i_last_bit, i_first_bit);
 			step_cpu_cnt *= i;
 			job_cpu_cnt *= i;
 		}
@@ -1333,7 +1333,7 @@ slurm_cred_unpack(Buf buffer, uint16_t protocol_version)
 		safe_unpackmem_xmalloc(sigp, &len, buffer);
 		cred->siglen = len;
 		xassert(len > 0);
-	} else if (protocol_version >= SLURM_2_5_PROTOCOL_VERSION) {
+	} else if (protocol_version >= SLURM_2_6_PROTOCOL_VERSION) {
 		safe_unpack32(&cred->jobid, buffer);
 		safe_unpack32(&cred->stepid, buffer);
 		safe_unpack32(&cred_uid, buffer);
