@@ -64,6 +64,7 @@
 #include "src/common/slurm_protocol_common.h"
 #include "src/common/slurm_protocol_defs.h"
 #include "src/common/slurm_protocol_util.h"
+#include "src/common/slurm_protocol_interface.h"
 
 #define MIN_NOALLOC_JOBID ((uint32_t) 0xffff0000)
 #define MAX_NOALLOC_JOBID ((uint32_t) 0xfffffffd)
@@ -88,6 +89,20 @@ enum {
  * protocol configuration functions
 \**********************************************************************/
 
+/* slurm_get_auth_info
+ * returns the auth_info from slurmctld_conf object (AuthInfo parameter)
+ * cache value in local buffer for best performance
+ * RET char *    - auth info,  MUST be xfreed by caller
+ */
+char *slurm_get_auth_info(void);
+
+/* slurm_get_auth_ttl
+ * returns the credential Time To Live option from the AuthInfo parameter
+ * cache value in local buffer for best performance
+ * RET int - Time To Live in seconds or 0 if not specified
+ */
+int slurm_get_auth_ttl(void);
+
 /* slurm_set_api_config
  * sets the slurm_protocol_config object
  * IN protocol_conf		-  slurm_protocol_config object
@@ -125,6 +140,11 @@ uint32_t slurm_get_suspend_time(void);
  */
 uint16_t slurm_get_complete_wait(void);
 
+/* slurm_get_cpu_freq_def
+ * RET CpuFreqDef value from slurm.conf
+ */
+uint32_t slurm_get_cpu_freq_def(void);
+
 /* slurm_get_prolog_flags
  * RET PrologFlags value from slurm.conf
  */
@@ -133,11 +153,11 @@ uint32_t slurm_get_prolog_flags(void);
 /* slurm_get_debug_flags
  * RET DebugFlags value from slurm.conf
  */
-uint32_t slurm_get_debug_flags(void);
+uint64_t slurm_get_debug_flags(void);
 
 /* slurm_set_debug_flags
  */
-void slurm_set_debug_flags(uint32_t debug_flags);
+void slurm_set_debug_flags(uint64_t debug_flags);
 
 /* slurm_get_def_mem_per_cpu
  * RET DefMemPerCPU/Node value from slurm.conf
@@ -164,6 +184,11 @@ uint32_t slurm_get_epilog_msg_time(void);
  */
 extern int slurm_get_env_timeout(void);
 
+/* slurm_get_max_array_size
+ * return MaxArraySize configuration parameter
+ */
+extern uint32_t slurm_get_max_array_size(void);
+
 /* slurm_get_mpi_default
  * get default mpi value from slurmctld_conf object
  * RET char *   - mpi default value from slurm.conf,  MUST be xfreed by caller
@@ -264,6 +289,10 @@ bool slurm_get_priority_favor_small(void);
  */
 uint32_t slurm_get_priority_max_age(void);
 
+/* slurm_get_priority_params
+ * RET char * - Value of PriorityParameters, MUST be xfreed by caller */
+char *slurm_get_priority_params(void);
+
 /* slurm_get_priority_reset_period
  * returns the priority usage reset period in seconds from slurmctld_conf object
  * RET uint16_t - flag, see PRIORITY_RESET_* in slurm/slurm.h.
@@ -360,6 +389,11 @@ extern char *slurm_get_crypto_type(void);
  */
 extern uint16_t slurm_get_fast_schedule(void);
 
+/* slurm_get_use_spec_resources
+ * returns the value of use_spec_resources in slurmctld_conf object
+ */
+extern uint16_t slurm_get_use_spec_resources(void);
+
 /* slurm_get_track_wckey
  * returns the value of track_wckey in slurmctld_conf object
  */
@@ -619,6 +653,12 @@ extern uint16_t slurm_get_ext_sensors_freq(void);
  * RET uint16_t  - Value of SchedulerRootFilter */
 extern uint16_t slurm_get_root_filter(void);
 
+/* slurm_get_route_plugin
+ * returns the value of route_plugin in slurmctld_conf object
+ * RET char *    - routing type, MUST be xfreed by caller
+ */
+extern char * slurm_get_route_plugin(void);
+
 /* slurm_get_sched_params
  * RET char * - Value of SchedulerParameters, MUST be xfreed by caller */
 extern char *slurm_get_sched_params(void);
@@ -690,6 +730,13 @@ char *slurm_get_srun_prolog(void);
  */
 char *slurm_get_srun_epilog(void);
 
+/* slurm_get_srun_port_range()
+ *
+ * Return the array with 2 members indicating the
+ * min and max ports that srun should use to listen to.
+ */
+uint16_t *slurm_get_srun_port_range(void);
+
 /* slurm_get_task_epilog
  * RET task_epilog name, must be xfreed by caller */
 char *slurm_get_task_epilog(void);
@@ -705,6 +752,9 @@ char *slurm_get_task_plugin(void);
 /* slurm_get_task_plugin_param */
 uint16_t slurm_get_task_plugin_param(void);
 
+/* Get SchedulerTimeSlice (secs) */
+uint16_t slurm_get_time_slice(void);
+
 /* slurm_get_core_spec_plugin
  * RET core_spec plugin name, must be xfreed by caller */
 char *slurm_get_core_spec_plugin(void);
@@ -713,6 +763,15 @@ char *slurm_get_core_spec_plugin(void);
  * RET job_container plugin name, must be xfreed by caller */
 char *slurm_get_job_container_plugin(void);
 
+/* slurm_get_slurmd_spooldir
+ * RET slurmd_spooldir name, must be xfreed by caller */
+char *slurm_get_slurmd_spooldir(void);
+
+/* slurm_get_layouts
+ * RET comma seperated list of layouts in a string, must be xfreed by caller
+ */
+char *slurm_get_layouts(void);
+
 /**********************************************************************\
  * general message management functions used by slurmctld, slurmd
 \**********************************************************************/
@@ -725,6 +784,21 @@ char *slurm_get_job_container_plugin(void);
  */
 extern slurm_fd_t slurm_init_msg_engine_port(uint16_t port);
 
+/* Creates a TCP socket and binds to a port in the given
+ * range.
+ *
+ * IN ports - range of ports from which to select the one
+ *            to bind
+ * RET slurm_fd - file descriptor of the listening socket
+ */
+extern slurm_fd_t slurm_init_msg_engine_ports(uint16_t *);
+
+/* sock_bind_range()
+ *
+ * Try to bind() sock to any port in a given interval of ports
+ */
+extern int sock_bind_range(int, uint16_t *);
+
 /* In the socket implementation it creates a socket, binds to it, and
  *	listens for connections.
  *
@@ -843,13 +917,6 @@ int slurm_send_node_msg(slurm_fd_t open_fd, slurm_msg_t *msg);
  */
 extern slurm_fd_t slurm_open_controller_conn(slurm_addr_t *addr);
 extern slurm_fd_t slurm_open_controller_conn_spec(enum controller_id dest);
-/* gets the slurm_addr_t of the specified controller
- *	primary or secondary slurmctld message engine
- * IN dest      - controller to contact, primary or secondary
- * OUT addr     - slurm_addr_t to the specified controller
- */
-void slurm_get_controller_addr_spec(enum controller_id dest,
-				    slurm_addr_t *addr);
 
 /* In the bsd socket implementation it creates a SOCK_STREAM socket
  *	and calls connect on it a SOCK_DGRAM socket called with connect
@@ -872,29 +939,6 @@ extern int slurm_shutdown_msg_conn(slurm_fd_t open_fd);
  * stream functions
 \**********************************************************************/
 
-/* slurm_listen_stream
- * opens a stream server and listens on it
- * IN slurm_address 	- slurm_addr_t to bind the server stream to
- * RET slurm_fd		- file descriptor of the stream created
- */
-extern slurm_fd_t slurm_listen_stream(slurm_addr_t * slurm_address);
-
-/* slurm_accept_stream
- * accepts a incoming stream connection on a stream server slurm_fd
- * IN open_fd		- file descriptor to accept connection on
- * OUT slurm_address 	- slurm_addr_t of the accepted connection
- * RET slurm_fd		- file descriptor of the accepted connection
- */
-extern slurm_fd_t slurm_accept_stream(slurm_fd_t open_fd,
-				    slurm_addr_t * slurm_address);
-
-/* slurm_open_stream
- * opens a client connection to stream server
- * IN slurm_address 	- slurm_addr_t of the connection destination
- * RET slurm_fd_t         - file descriptor of the connection created
- */
-extern slurm_fd_t slurm_open_stream(slurm_addr_t * slurm_address);
-
 /* slurm_close_stream
  * closes either a server or client stream file_descriptor
  * IN open_fd	- an open file descriptor to close
