@@ -44,6 +44,7 @@
 
 #include "src/common/log.h"
 #include "src/common/slurm_protocol_api.h"
+#include "src/common/slurm_protocol_defs.h"
 #include "src/common/slurm_protocol_util.h"
 #include "src/common/slurmdbd_defs.h"
 #include "src/common/xmalloc.h"
@@ -53,10 +54,8 @@ uint16_t _get_slurm_version(uint32_t rpc_version)
 {
 	if (rpc_version >= SLURM_PROTOCOL_VERSION)
 		return SLURM_PROTOCOL_VERSION;
-	else if (rpc_version >= SLURMDBD_2_6_VERSION)
-		return SLURM_2_6_PROTOCOL_VERSION;
 	else
-		return SLURM_2_5_PROTOCOL_VERSION;
+		return SLURM_2_6_PROTOCOL_VERSION;
 }
 
 /*
@@ -76,10 +75,11 @@ int check_header_version(header_t * header)
 
 	if (slurmdbd_conf) {
 		if ((header->version != SLURM_PROTOCOL_VERSION)     &&
-		    (header->version != SLURM_2_6_PROTOCOL_VERSION) &&
-		    (header->version != SLURM_2_5_PROTOCOL_VERSION)) {
-			debug("unsupported RPC version %hu msg type %u",
-			      header->version, header->msg_type);
+		    (header->version != SLURM_14_03_PROTOCOL_VERSION) &&
+		    (header->version != SLURM_2_6_PROTOCOL_VERSION)) {
+			debug("unsupported RPC version %hu msg type %s(%u)",
+			      header->version, rpc_num2string(header->msg_type),
+			      header->msg_type);
 			slurm_seterrno_ret(SLURM_PROTOCOL_VERSION_ERROR);
 		}
 	} else if (header->version != check_version) {
@@ -88,17 +88,24 @@ int check_header_version(header_t * header)
 		case REQUEST_RUN_JOB_STEP:
 		case RESPONSE_LAUNCH_TASKS:
 		case RESPONSE_RUN_JOB_STEP:
-			/* Disable job step creation/launch between major
-			 * releases. Other RPCs should all be supported. */
-			debug("unsupported RPC type %hu", header->msg_type);
-			slurm_seterrno_ret(SLURM_PROTOCOL_VERSION_ERROR);
-			break;
+			if (working_cluster_rec) {
+				/* Disable job step creation/launch
+				 * between major releases. Other RPCs
+				 * should all be supported. */
+				debug("unsupported RPC type %hu",
+				      header->msg_type);
+				slurm_seterrno_ret(
+					SLURM_PROTOCOL_VERSION_ERROR);
+				break;
+			}
 		default:
 			if ((header->version != SLURM_PROTOCOL_VERSION)     &&
-			    (header->version != SLURM_2_6_PROTOCOL_VERSION) &&
-			    (header->version != SLURM_2_5_PROTOCOL_VERSION)) {
-				debug("Unsupported RPC version %hu msg type %u",
-				      header->version, header->msg_type);
+			    (header->version != SLURM_14_03_PROTOCOL_VERSION) &&
+			    (header->version != SLURM_2_6_PROTOCOL_VERSION)) {
+				debug("Unsupported RPC version %hu "
+				      "msg type %s(%u)", header->version,
+				      rpc_num2string(header->msg_type),
+				      header->msg_type);
 				slurm_seterrno_ret(SLURM_PROTOCOL_VERSION_ERROR);
 			}
 			break;
