@@ -49,6 +49,8 @@
 #include "src/common/slurm_auth.h"
 #include "src/slurmdbd/read_config.h"
 
+#define FORMAT_STRING_SIZE 34
+
 slurmdb_cluster_rec_t *working_cluster_rec = NULL;
 
 static void _free_res_cond_members(slurmdb_res_cond_t *res_cond);
@@ -331,8 +333,7 @@ static int _setup_cluster_rec(slurmdb_cluster_rec_t *cluster_rec)
 			i--;
 
 		if (i > 0) {
-			char *p = '\0';
-			number = xstrntol(nodes + i, &p,
+			number = xstrntol(nodes + i, NULL,
 					  cluster_rec->dimensions, 36);
 			hostlist_parse_int_to_array(
 				number, cluster_rec->dim_size,
@@ -383,6 +384,7 @@ extern slurmdb_job_rec_t *slurmdb_create_job_rec()
 {
 	slurmdb_job_rec_t *job = xmalloc(sizeof(slurmdb_job_rec_t));
 	memset(&job->stats, 0, sizeof(slurmdb_stats_t));
+	job->array_task_id = NO_VAL;
 	job->derived_ec = NO_VAL;
 	job->stats.cpu_min = NO_VAL;
 	job->state = JOB_PENDING;
@@ -530,12 +532,16 @@ extern void slurmdb_destroy_job_rec(void *object)
 	slurmdb_job_rec_t *job = (slurmdb_job_rec_t *)object;
 	if (job) {
 		xfree(job->account);
+		xfree(job->alloc_gres);
+		xfree(job->array_task_str);
 		xfree(job->blockid);
 		xfree(job->cluster);
 		xfree(job->derived_es);
 		xfree(job->jobname);
 		xfree(job->partition);
 		xfree(job->nodes);
+		xfree(job->req_gres);
+		xfree(job->resv_name);
 		if (job->steps) {
 			list_destroy(job->steps);
 			job->steps = NULL;
@@ -1205,6 +1211,8 @@ extern void slurmdb_init_qos_rec(slurmdb_qos_rec_t *qos, bool free_it)
 	qos->max_submit_jobs_pu = NO_VAL;
 	qos->max_wall_pj = NO_VAL;
 
+	qos->min_cpus_pj = NO_VAL;
+
 	qos->usage_factor = (double)NO_VAL;
 	qos->usage_thres = (double)NO_VAL;
 }
@@ -2479,3 +2487,30 @@ extern slurmdb_report_cluster_rec_t *slurmdb_cluster_rec_2_report(
 
 	return slurmdb_report_cluster;
 }
+
+extern char *slurmdb_get_selected_step_id(
+	char *job_id_str, int len,
+	slurmdb_selected_step_t *selected_step)
+{
+	char id[FORMAT_STRING_SIZE];
+
+	xassert(selected_step);
+
+	if (selected_step->array_task_id != NO_VAL)
+		snprintf(id, FORMAT_STRING_SIZE,
+			 "%u_%u",
+			 selected_step->jobid,
+			 selected_step->array_task_id);
+	else
+		snprintf(id, FORMAT_STRING_SIZE,
+			 "%u",
+			 selected_step->jobid);
+
+	if (selected_step->stepid != NO_VAL)
+		snprintf(job_id_str, len, "%s.%u",
+			 id, selected_step->stepid);
+	else
+		snprintf(job_id_str, len, "%s", id);
+
+	return job_id_str;
+}
