@@ -251,6 +251,7 @@ static int _mysql_make_table_current(mysql_conn_t *mysql_conn, char *table_name,
 	if (!(result = mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
 		xfree(old_index);
+		FREE_NULL_LIST(keys_list);
 		return SLURM_ERROR;
 	}
 	xfree(query);
@@ -707,6 +708,13 @@ extern int mysql_db_get_db_connection(mysql_conn_t *mysql_conn, char *db_name,
 				}
 			} else {
 				storage_init = true;
+				if (mysql_conn->rollback)
+					mysql_autocommit(
+						mysql_conn->db_conn, 0);
+				rc = _mysql_query_internal(
+					mysql_conn->db_conn,
+					"SET session sql_mode='ANSI_QUOTES,"
+					"NO_ENGINE_SUBSTITUTION';");
 			}
 		}
 	}
@@ -755,6 +763,25 @@ extern int mysql_db_query(mysql_conn_t *mysql_conn, char *query)
 	return rc;
 }
 
+/*
+ * Executes a single delete sql query.
+ * Returns the number of deleted rows, <0 for failure.
+ */
+extern int mysql_db_delete_affected_rows(mysql_conn_t *mysql_conn, char *query)
+{
+	int rc = SLURM_SUCCESS;
+
+	if (!mysql_conn || !mysql_conn->db_conn) {
+		fatal("You haven't inited this storage yet.");
+		return 0;	/* For CLANG false positive */
+	}
+	slurm_mutex_lock(&mysql_conn->lock);
+	if (!(rc = _mysql_query_internal(mysql_conn->db_conn, query)))
+			rc = mysql_affected_rows(mysql_conn->db_conn);
+	slurm_mutex_unlock(&mysql_conn->lock);
+	return rc;
+}
+
 extern int mysql_db_ping(mysql_conn_t *mysql_conn)
 {
 	int rc;
