@@ -851,6 +851,12 @@ static void _process_terminated(List job_list, char *f[], int lc,
 	filetxt_job_rec_t *temp = NULL;
 
 	_parse_line(f, (void **)&temp, len);
+
+	if (temp == NULL) {
+		error("Unknown proccess terminated");
+		return;
+	}
+
 	job = _find_job_record(job_list, temp->header, JOB_TERMINATED);
 	if (!job) {	/* fake it for now */
 		job = _create_filetxt_job_rec(temp->header);
@@ -1103,8 +1109,9 @@ extern List filetxt_jobacct_process_get_jobs(slurmdb_job_cond_t *job_cond)
 					if (curr_job->jobid ==
 					    slurmdb_job->jobid) {
 						list_delete_item(itr2);
-						info("removing job %d",
-						     slurmdb_job->jobid);
+						debug3("removing duplicate "
+						       "of job %d",
+						       slurmdb_job->jobid);
 						break;
 					}
 				}
