@@ -230,8 +230,8 @@ static int _reset_default_assoc(mysql_conn_t *mysql_conn,
 			   "where (user='%s' && acct!='%s' && is_def=1);",
 			   assoc->cluster, assoc_table,
 			   assoc->user, assoc->acct);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, sel_query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", sel_query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, sel_query, 1))) {
 			xfree(sel_query);
@@ -327,8 +327,8 @@ static int _make_sure_users_have_default(
 				"user='%s' and acct='%s';",
 				cluster, assoc_table, user, acct);
 			xfree(acct);
-			debug3("%d(%s:%d) query\n%s",
-			       mysql_conn->conn, THIS_FILE, __LINE__, query);
+			if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+				DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 			rc = mysql_db_query(mysql_conn, query);
 			xfree(query);
 			if (rc != SLURM_SUCCESS) {
@@ -363,8 +363,8 @@ static int _move_account(mysql_conn_t *mysql_conn, uint32_t *lft, uint32_t *rgt,
 	char *query = xstrdup_printf(
 		"SELECT lft from \"%s_%s\" where acct='%s' && user='';",
 		cluster, assoc_table, parent);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(
 		      mysql_conn, query, 0))) {
 		xfree(query);
@@ -382,8 +382,10 @@ static int _move_account(mysql_conn_t *mysql_conn, uint32_t *lft, uint32_t *rgt,
 	diff = ((par_left + 1) - *lft);
 
 	if (diff == 0) {
-		debug3("Trying to move association to the same position?  "
-		       "Nothing to do.");
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn,
+				 "Trying to move association to the same "
+				 "position?  Nothing to do.");
 		return ESLURM_SAME_PARENT_ACCOUNT;
 	}
 
@@ -433,8 +435,8 @@ static int _move_account(mysql_conn_t *mysql_conn, uint32_t *lft, uint32_t *rgt,
 	xstrfmtcat(query,
 		   "select lft, rgt from \"%s_%s\" where id_assoc = %s",
 		   cluster, assoc_table, id);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(mysql_conn, query, 1))) {
 		xfree(query);
 		return SLURM_ERROR;
@@ -477,8 +479,8 @@ static int _move_parent(mysql_conn_t *mysql_conn, uid_t uid,
 		"&& acct='%s' && user='' order by lft;",
 		cluster, assoc_table, *lft, *rgt,
 		new_parent);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result =
 	      mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
@@ -508,8 +510,8 @@ static int _move_parent(mysql_conn_t *mysql_conn, uid_t uid,
 	query = xstrdup_printf(
 		"select lft, rgt from \"%s_%s\" where id_assoc=%s;",
 		cluster, assoc_table, id);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result =
 	      mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
@@ -787,8 +789,8 @@ static int _modify_unset_users(mysql_conn_t *mysql_conn,
 			       object, assoc->cluster, assoc_table,
 			       lft, rgt, acct, acct);
 	xfree(object);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result =
 	      mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
@@ -888,6 +890,7 @@ static int _modify_unset_users(mysql_conn_t *mysql_conn,
 			list_iterator_destroy(qos_itr);
 			if (delta_itr)
 				list_iterator_destroy(delta_itr);
+			FREE_NULL_LIST(delta_qos_list);
 			if (list_count(mod_assoc->qos_list)
 			    || !list_count(assoc->qos_list))
 				modified = 1;
@@ -998,7 +1001,6 @@ static char *_setup_association_cond_qos(slurmdb_association_cond_t *assoc_cond,
 		list_iterator_destroy(itr);
 		xstrcat(extra, ") &&");
 	} else if (assoc_cond->with_sub_accts) {
-		prefix = "t2";
 		xstrfmtcat(extra, ", \"%s_%s\" as t2 where "
 			   "(t1.lft between t2.lft and t2.rgt) &&",
 			   cluster_name, assoc_table);
@@ -1557,7 +1559,7 @@ static int _process_modify_assoc_results(mysql_conn_t *mysql_conn,
 			xfree(query);
 
 			if ((row2 = mysql_fetch_row(result2))) {
-				if (!assoc->def_qos_id
+				if (assoc->def_qos_id == INFINITE
 				    && row2[ASSOC2_REQ_DEF_QOS])
 					assoc->def_qos_id = slurm_atoul(
 						row2[ASSOC2_REQ_DEF_QOS]);
@@ -1806,8 +1808,8 @@ static int _process_modify_assoc_results(mysql_conn_t *mysql_conn,
 	}
 
 	if (reset_query) {
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, reset_query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", reset_query);
 		if ((rc = mysql_db_query(mysql_conn, reset_query))
 		    != SLURM_SUCCESS)
 			error("Couldn't update defaults");
@@ -1997,8 +1999,8 @@ static int _cluster_get_assocs(mysql_conn_t *mysql_conn,
 			}
 			list_iterator_destroy(itr);
 		}
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(extra);
@@ -2010,12 +2012,12 @@ static int _cluster_get_assocs(mysql_conn_t *mysql_conn,
 		while ((row = mysql_fetch_row(result))) {
 			if (set) {
 				xstrfmtcat(extra,
-					   " || (%s between lft and rgt)",
+					   " || (%s between t1.lft and t1.rgt)",
 					   row[0]);
 			} else {
 				set = 1;
 				xstrfmtcat(extra,
-					   " && ((%s between lft and rgt)",
+					   " && ((%s between t1.lft and t1.rgt)",
 					   row[0]);
 			}
 		}
@@ -2044,8 +2046,8 @@ static int _cluster_get_assocs(mysql_conn_t *mysql_conn,
 			       qos_extra, extra);
 	xfree(qos_extra);
 	xfree(extra);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(
 		      mysql_conn, query, 0))) {
 		xfree(query);
@@ -2193,7 +2195,7 @@ static int _cluster_get_assocs(mysql_conn_t *mysql_conn,
 
 				if (row2[ASSOC2_REQ_MNPJ])
 					parent_mnpj = slurm_atoul(
-							row2[ASSOC2_REQ_MNPJ]);
+						row2[ASSOC2_REQ_MNPJ]);
 				else
 					parent_mnpj = INFINITE;
 
@@ -2390,9 +2392,8 @@ extern int as_mysql_get_modified_lfts(mysql_conn_t *mysql_conn,
 		"select id_assoc, lft from \"%s_%s\" where lft > %u "
 		"&& deleted = 0",
 		cluster_name, assoc_table, start_lft);
-
-	debug3("%d(%d) query\n%s",
-	       mysql_conn->conn, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(
 		      mysql_conn, query, 0))) {
 		xfree(query);
@@ -2449,6 +2450,47 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
 
+	if (!is_user_min_admin_level(mysql_conn, uid, SLURMDB_ADMIN_OPERATOR)) {
+		ListIterator itr2 = NULL;
+		slurmdb_user_rec_t user;
+		slurmdb_coord_rec_t *coord = NULL;
+		slurmdb_association_rec_t *object = NULL;
+
+		memset(&user, 0, sizeof(slurmdb_user_rec_t));
+		user.uid = uid;
+
+		if (!is_user_any_coord(mysql_conn, &user)) {
+			error("Only admins/operators/coordinators "
+			      "can add associations");
+			return ESLURM_ACCESS_DENIED;
+		}
+
+		itr = list_iterator_create(association_list);
+		itr2 = list_iterator_create(user.coord_accts);
+		while ((object = list_next(itr))) {
+			char *account = "root";
+			if (object->user)
+				account = object->acct;
+			else if (object->parent_acct)
+				account = object->parent_acct;
+			list_iterator_reset(itr2);
+			while ((coord = list_next(itr2))) {
+				if (!strcasecmp(coord->name, account))
+					break;
+			}
+			if (!coord)
+				break;
+		}
+		list_iterator_destroy(itr2);
+		list_iterator_destroy(itr);
+		if (!coord)  {
+			error("Coordinator %s(%d) tried to add associations "
+			      "where they were not allowed",
+			      user.name, user.uid);
+			return ESLURM_ACCESS_DENIED;
+		}
+	}
+
 	local_cluster_list = list_create(NULL);
 	user_name = uid_to_string((uid_t) uid);
 	/* these need to be in a specific order */
@@ -2527,8 +2569,8 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 			   "FOR UPDATE;",
 			   tmp_char, object->cluster, assoc_table, update);
 		xfree(tmp_char);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(query);
@@ -2582,9 +2624,10 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 						old_cluster, assoc_table,
 						incr, my_left,
 						old_cluster, assoc_table);
-					debug3("%d(%s:%d) query\n%s",
-					       mysql_conn->conn,
-					       THIS_FILE, __LINE__, up_query);
+					if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+						DB_DEBUG(mysql_conn->conn,
+							 "query\n%s",
+							 up_query);
 					rc = mysql_db_query(
 						mysql_conn,
 						up_query);
@@ -2600,8 +2643,9 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 					}
 				}
 
-				debug3("%d(%s:%d) query\n%s", mysql_conn->conn,
-				       THIS_FILE, __LINE__, sel_query);
+				if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+					DB_DEBUG(mysql_conn->conn, "query\n%s",
+						 sel_query);
 				if (!(sel_result = mysql_db_query_ret(
 					      mysql_conn,
 					      sel_query, 0))) {
@@ -2713,8 +2757,8 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 		xfree(cols);
 		xfree(vals);
 		xfree(update);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		rc = mysql_db_query(mysql_conn, query);
 		xfree(query);
 		if (rc != SLURM_SUCCESS) {
@@ -2805,8 +2849,8 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 			old_cluster, assoc_table, incr,
 			my_left,
 			old_cluster, assoc_table);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, up_query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", up_query);
 		rc = mysql_db_query(mysql_conn, up_query);
 		xfree(up_query);
 		if (rc != SLURM_SUCCESS)
@@ -2927,8 +2971,8 @@ extern int as_mysql_add_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 	}
 	list_iterator_destroy(itr);
 	if (query) {
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		rc = mysql_db_query(mysql_conn, query);
 		xfree(query);
 		if (rc != SLURM_SUCCESS)
@@ -2938,6 +2982,7 @@ end_it:
 
 	if (rc != SLURM_ERROR) {
 		_make_sure_users_have_default(mysql_conn, added_user_list);
+		FREE_NULL_LIST(added_user_list);
 
 		if (txn_query) {
 			xstrcat(txn_query, ";");
@@ -2994,8 +3039,7 @@ end_it:
 			list_destroy(assoc_list);
 		}
 	} else {
-		if (added_user_list)
-			list_destroy(added_user_list);
+		FREE_NULL_LIST(added_user_list);
 		xfree(txn_query);
 		reset_mysql_conn(mysql_conn);
 	}
@@ -3119,8 +3163,8 @@ is_same_user:
 			   object, cluster_name,
 			   assoc_table, qos_extra, extra);
 		xfree(qos_extra);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(query);
@@ -3161,7 +3205,8 @@ is_same_user:
 	} else if (!list_count(ret_list)) {
 		reset_mysql_conn(mysql_conn);
 		errno = SLURM_NO_CHANGE_IN_DATA;
-		debug3("didn't effect anything");
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "didn't effect anything");
 		return ret_list;
 	}
 
@@ -3233,8 +3278,8 @@ extern List as_mysql_remove_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 				       cluster_name, assoc_table,
 				       qos_extra, extra);
 		xfree(qos_extra);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(query);
@@ -3268,8 +3313,8 @@ extern List as_mysql_remove_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 				       "and deleted = 0 order by lft;",
 				       object,
 				       cluster_name, assoc_table, name_char);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(query);
@@ -3305,7 +3350,8 @@ extern List as_mysql_remove_assocs(mysql_conn_t *mysql_conn, uint32_t uid,
 	} else if (!list_count(ret_list)) {
 		reset_mysql_conn(mysql_conn);
 		errno = SLURM_NO_CHANGE_IN_DATA;
-		debug3("didn't effect anything");
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "didn't effect anything");
 		return ret_list;
 	}
 	if (jobs_running)
