@@ -186,8 +186,8 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 			   cluster_table,
 			   now, now, object->name, object->classification,
 			   now, object->classification);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		rc = mysql_db_query(mysql_conn, query);
 		xfree(query);
 		if (rc != SLURM_SUCCESS) {
@@ -220,8 +220,8 @@ extern int as_mysql_add_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 
 		xfree(cols);
 		xfree(vals);
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 
 		rc = mysql_db_query(mysql_conn, query);
 		xfree(query);
@@ -403,8 +403,8 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 	xstrfmtcat(query, "select name, control_port from %s%s;",
 		   cluster_table, extra);
 
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(
 		      mysql_conn, query, 0))) {
 		xfree(query);
@@ -432,7 +432,9 @@ extern List as_mysql_modify_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 
 	if (!list_count(ret_list)) {
 		errno = SLURM_NO_CHANGE_IN_DATA;
-		debug3("didn't effect anything\n%s", query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn,
+				 "didn't effect anything\n%s", query);
 		xfree(vals);
 		xfree(query);
 		return ret_list;
@@ -509,7 +511,9 @@ extern List as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 	if (!mysql_num_rows(result)) {
 		mysql_free_result(result);
 		errno = SLURM_NO_CHANGE_IN_DATA;
-		debug3("didn't effect anything\n%s", query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn,
+				 "didn't effect anything\n%s", query);
 		xfree(query);
 		return ret_list;
 	}
@@ -555,8 +559,8 @@ extern List as_mysql_remove_clusters(mysql_conn_t *mysql_conn, uint32_t uid,
 		return NULL;
 	}
 	if (!jobs_running) {
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		rc = mysql_db_query(mysql_conn, query);
 		xfree(query);
 		if (rc != SLURM_SUCCESS) {
@@ -663,8 +667,8 @@ empty:
 	xfree(tmp);
 	xfree(extra);
 
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(
 		      mysql_conn, query, 0))) {
 		xfree(query);
@@ -975,8 +979,8 @@ empty:
 		if (extra)
 			xstrfmtcat(query, " %s", extra);
 
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(query);
@@ -1038,10 +1042,17 @@ extern int as_mysql_node_down(mysql_conn_t *mysql_conn,
 	int rc = SLURM_SUCCESS;
 	char *query = NULL;
 	char *my_reason;
+	MYSQL_RES *result = NULL;
+	MYSQL_ROW row;
 
 	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
 
+	if (!mysql_conn->cluster_name) {
+		error("%s:%d no cluster name", THIS_FILE, __LINE__);
+		return SLURM_ERROR;
+	}
+
 	if (!node_ptr) {
 		error("No node_ptr given!");
 		return SLURM_ERROR;
@@ -1052,11 +1063,36 @@ extern int as_mysql_node_down(mysql_conn_t *mysql_conn,
 	else
 		cpus = node_ptr->cpus;
 
+	query = xstrdup_printf("select state, reason from \"%s_%s\" where "
+			       "time_end=0 and node_name='%s';",
+			       mysql_conn->cluster_name, event_table,
+			       node_ptr->name);
+	/* info("%d(%s:%d) query\n%s", */
+	/*        mysql_conn->conn, THIS_FILE, __LINE__, query); */
+	result = mysql_db_query_ret(mysql_conn, query, 0);
+	xfree(query);
+
+	if (!result)
+		return SLURM_ERROR;
+
 	if (reason)
 		my_reason = slurm_add_slash_to_quotes(reason);
 	else
 		my_reason = slurm_add_slash_to_quotes(node_ptr->reason);
 
+	row = mysql_fetch_row(result);
+	if (row && (node_ptr->node_state == slurm_atoul(row[0])) &&
+	    my_reason && row[1] &&
+	    !strcasecmp(my_reason, row[1])) {
+		debug("as_mysql_node_down: no change needed %u == %s "
+		      "and %s == %s",
+		     node_ptr->node_state, row[0], my_reason, row[1]);
+		xfree(my_reason);
+		mysql_free_result(result);
+		return SLURM_SUCCESS;
+	}
+	mysql_free_result(result);
+
 	debug2("inserting %s(%s) with %u cpus",
 	       node_ptr->name, mysql_conn->cluster_name, cpus);
 
@@ -1100,6 +1136,11 @@ extern int as_mysql_node_up(mysql_conn_t *mysql_conn,
 	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
 
+	if (!mysql_conn->cluster_name) {
+		error("%s:%d no cluster name", THIS_FILE, __LINE__);
+		return SLURM_ERROR;
+	}
+
 	query = xstrdup_printf(
 		"update \"%s_%s\" set time_end=%ld where "
 		"time_end=0 and node_name='%s';",
@@ -1129,6 +1170,11 @@ extern int as_mysql_register_ctld(mysql_conn_t *mysql_conn,
 	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
 
+	if (!mysql_conn->cluster_name) {
+		error("%s:%d no cluster name", THIS_FILE, __LINE__);
+		return SLURM_ERROR;
+	}
+
 	if (!mysql_conn->cluster_name)
 		mysql_conn->cluster_name = xstrdup(cluster);
 
@@ -1159,8 +1205,8 @@ extern int as_mysql_register_ctld(mysql_conn_t *mysql_conn,
 		   slurmctld_conf.slurm_user_name, address, port,
 		   SYSTEM_DIMENSIONS, flags, select_get_plugin_id());
 
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_ASSOC)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 
 	rc = mysql_db_query(mysql_conn, query);
 	xfree(query);
@@ -1188,8 +1234,8 @@ extern int as_mysql_fini_ctld(mysql_conn_t *mysql_conn,
 		"control_host='%s' && control_port=%u;",
 		cluster_table, now, cluster_rec->name,
 		cluster_rec->control_host, cluster_rec->control_port);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_EVENT)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	rc = mysql_db_query(mysql_conn, query);
 	xfree(query);
 
@@ -1229,8 +1275,8 @@ extern int as_mysql_fini_ctld(mysql_conn_t *mysql_conn,
 		"values ('%u', %u, %ld, 'slurmctld disconnect')",
 		cluster_rec->name, event_table,
 		cluster_rec->cpu_count, NODE_STATE_DOWN, (long)now);
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_EVENT)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	rc = mysql_db_query(mysql_conn, query);
 	xfree(query);
 
@@ -1250,6 +1296,11 @@ extern int as_mysql_cluster_cpus(mysql_conn_t *mysql_conn,
  	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
 
+	if (!mysql_conn->cluster_name) {
+		error("%s:%d no cluster name", THIS_FILE, __LINE__);
+		return SLURM_ERROR;
+	}
+
 	/* Record the processor count */
 	query = xstrdup_printf(
 		"select cpu_count, cluster_nodes from \"%s_%s\" where "
@@ -1295,9 +1346,11 @@ extern int as_mysql_cluster_cpus(mysql_conn_t *mysql_conn,
 	}
 
 	if (slurm_atoul(row[0]) == cpus) {
-		debug3("we have the same cpu count as before for %s, "
-		       "no need to update the database.",
-		       mysql_conn->cluster_name);
+		if (debug_flags & DEBUG_FLAG_DB_EVENT)
+			DB_DEBUG(mysql_conn->conn,
+				 "we have the same cpu count as before for %s, "
+				 "no need to update the database.",
+				 mysql_conn->cluster_name);
 		if (cluster_nodes) {
 			if (!row[1][0]) {
 				debug("Adding cluster nodes '%s' to "
@@ -1309,20 +1362,24 @@ extern int as_mysql_cluster_cpus(mysql_conn_t *mysql_conn,
 					"where time_end=0 and node_name=''",
 					mysql_conn->cluster_name,
 					event_table, cluster_nodes);
-				rc = mysql_db_query(mysql_conn, query);
+				(void) mysql_db_query(mysql_conn, query);
 				xfree(query);
 				goto update_it;
 			} else if (!strcmp(cluster_nodes, row[1])) {
-				debug3("we have the same nodes in the cluster "
-				       "as before no need to "
-				       "update the database.");
+				if (debug_flags & DEBUG_FLAG_DB_EVENT)
+					DB_DEBUG(mysql_conn->conn,
+						 "we have the same nodes "
+						 "in the cluster "
+						 "as before no need to "
+						 "update the database.");
 				goto update_it;
 			}
 		} else
 			goto end_it;
-	} else
+	} else {
 		debug("%s has changed from %s cpus to %u",
 		      mysql_conn->cluster_name, row[0], cpus);
+	}
 
 	/* reset all the entries for this cluster since the cpus
 	   changed some of the downed nodes may have gone away.
@@ -1342,7 +1399,7 @@ add_it:
 		"values ('%s', %u, %ld, 'Cluster processor count')",
 		mysql_conn->cluster_name, event_table,
 		cluster_nodes, cpus, event_time);
-	rc = mysql_db_query(mysql_conn, query);
+	(void) mysql_db_query(mysql_conn, query);
 	xfree(query);
 update_it:
 	query = xstrdup_printf(
