@@ -55,17 +55,22 @@ typedef struct {
  * enum below also t1 is job_table */
 char *job_req_inx[] = {
 	"t1.account",
+	"t1.array_max_tasks",
+	"t1.array_task_str",
 	"t1.cpus_alloc",
 	"t1.cpus_req",
 	"t1.derived_ec",
 	"t1.derived_es",
 	"t1.exit_code",
+	"t1.id_array_job",
+	"t1.id_array_task",
 	"t1.id_assoc",
 	"t1.id_block",
 	"t1.id_group",
 	"t1.id_job",
 	"t1.id_qos",
 	"t1.id_resv",
+	"t3.resv_name",
 	"t1.id_user",
 	"t1.id_wckey",
 	"t1.job_db_inx",
@@ -86,6 +91,9 @@ char *job_req_inx[] = {
 	"t1.timelimit",
 	"t1.track_steps",
 	"t1.wckey",
+	"t1.gres_alloc",
+	"t1.gres_req",
+	"t1.gres_used",
 	"t2.acct",
 	"t2.lft",
 	"t2.user"
@@ -93,17 +101,22 @@ char *job_req_inx[] = {
 
 enum {
 	JOB_REQ_ACCOUNT1,
+	JOB_REQ_ARRAY_MAX,
+	JOB_REQ_ARRAY_STR,
 	JOB_REQ_ALLOC_CPUS,
 	JOB_REQ_REQ_CPUS,
 	JOB_REQ_DERIVED_EC,
 	JOB_REQ_DERIVED_ES,
 	JOB_REQ_EXIT_CODE,
+	JOB_REQ_ARRAYJOBID,
+	JOB_REQ_ARRAYTASKID,
 	JOB_REQ_ASSOCID,
 	JOB_REQ_BLOCKID,
 	JOB_REQ_GID,
 	JOB_REQ_JOBID,
 	JOB_REQ_QOS,
 	JOB_REQ_RESVID,
+	JOB_REQ_RESV_NAME,
 	JOB_REQ_UID,
 	JOB_REQ_WCKEYID,
 	JOB_REQ_ID,
@@ -124,6 +137,9 @@ enum {
 	JOB_REQ_TIMELIMIT,
 	JOB_REQ_TRACKSTEPS,
 	JOB_REQ_WCKEY,
+	JOB_REQ_GRES_ALLOC,
+	JOB_REQ_GRES_REQ,
+	JOB_REQ_GRES_USED,
 	JOB_REQ_ACCOUNT,
 	JOB_REQ_LFT,
 	JOB_REQ_USER_NAME,
@@ -374,8 +390,8 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 			}
 			list_iterator_destroy(itr);
 		}
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn->conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_JOB)
+			DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 		if (!(result = mysql_db_query_ret(
 			      mysql_conn, query, 0))) {
 			xfree(extra);
@@ -426,9 +442,12 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 
 	query = xstrdup_printf("select %s from \"%s_%s\" as t1 "
 			       "left join \"%s_%s\" as t2 "
-			       "on t1.id_assoc=t2.id_assoc",
+			       "on t1.id_assoc=t2.id_assoc "
+			       "left join \"%s_%s\" as t3 "
+			       " on t1.id_resv=t3.id_resv ",
 			       job_fields, cluster_name, job_table,
-			       cluster_name, assoc_table);
+			       cluster_name, assoc_table,
+			       cluster_name, resv_table);
 	if (extra) {
 		xstrcat(query, extra);
 		xfree(extra);
@@ -440,8 +459,8 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 	*/
 	xstrcat(query, " group by id_job, time_submit desc");
 
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_JOB)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
 		rc = SLURM_ERROR;
@@ -468,7 +487,7 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 	while ((row = mysql_fetch_row(result))) {
 		char *id = row[JOB_REQ_ID];
 		bool job_ended = 0;
-		int submit = slurm_atoul(row[JOB_REQ_SUBMIT]);
+		int start = slurm_atoul(row[JOB_REQ_START]);
 
 		curr_id = slurm_atoul(row[JOB_REQ_JOBID]);
 
@@ -479,9 +498,11 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 
 		/* check the bitmap to see if this is one of the jobs
 		   we are looking for */
+		/* Use start time instead of submit time because node
+		 * indexes are determined at start time and not submit. */
 		if (!good_nodes_from_inx(local_cluster_list,
 					 (void **)&curr_cluster,
-					 row[JOB_REQ_NODE_INX], submit)) {
+					 row[JOB_REQ_NODE_INX], start)) {
 			last_id = curr_id;
 			continue;
 		}
@@ -498,9 +519,19 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 		last_id = curr_id;
 
 		job->alloc_cpus = slurm_atoul(row[JOB_REQ_ALLOC_CPUS]);
+		if (row[JOB_REQ_GRES_ALLOC])
+			job->alloc_gres = xstrdup(row[JOB_REQ_GRES_ALLOC]);
+		else
+			job->alloc_gres = xstrdup("");
 		job->alloc_nodes = slurm_atoul(row[JOB_REQ_ALLOC_NODES]);
 		job->associd = slurm_atoul(row[JOB_REQ_ASSOCID]);
+		job->array_job_id = slurm_atoul(row[JOB_REQ_ARRAYJOBID]);
+		job->array_task_id = slurm_atoul(row[JOB_REQ_ARRAYTASKID]);
 		job->resvid = slurm_atoul(row[JOB_REQ_RESVID]);
+
+		if (row[JOB_REQ_RESV_NAME] && row[JOB_REQ_RESV_NAME][0])
+			job->resv_name = xstrdup(row[JOB_REQ_RESV_NAME]);
+
 		job->cluster = xstrdup(cluster_name);
 
 		/* we want a blank wckey if the name is null */
@@ -523,12 +554,19 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 		else if (row[JOB_REQ_ACCOUNT1] && row[JOB_REQ_ACCOUNT1][0])
 			job->account = xstrdup(row[JOB_REQ_ACCOUNT1]);
 
+		if (row[JOB_REQ_ARRAY_STR] && row[JOB_REQ_ARRAY_STR][0])
+			job->array_task_str = xstrdup(row[JOB_REQ_ARRAY_STR]);
+
+		if (row[JOB_REQ_ARRAY_MAX])
+			job->array_max_tasks =
+				slurm_atoul(row[JOB_REQ_ARRAY_MAX]);
+
 		if (row[JOB_REQ_BLOCKID])
 			job->blockid = xstrdup(row[JOB_REQ_BLOCKID]);
 
 		job->eligible = slurm_atoul(row[JOB_REQ_ELIGIBLE]);
-		job->submit = submit;
-		job->start = slurm_atoul(row[JOB_REQ_START]);
+		job->submit = slurm_atoul(row[JOB_REQ_SUBMIT]);
+		job->start = start;
 		job->end = slurm_atoul(row[JOB_REQ_END]);
 		job->timelimit = slurm_atoul(row[JOB_REQ_TIMELIMIT]);
 
@@ -644,6 +682,10 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 		job->track_steps = slurm_atoul(row[JOB_REQ_TRACKSTEPS]);
 		job->priority = slurm_atoul(row[JOB_REQ_PRIORITY]);
 		job->req_cpus = slurm_atoul(row[JOB_REQ_REQ_CPUS]);
+		if (row[JOB_REQ_GRES_REQ])
+			job->req_gres = xstrdup(row[JOB_REQ_GRES_REQ]);
+		else
+			job->req_gres = xstrdup("");
 		job->req_mem = slurm_atoul(row[JOB_REQ_REQ_MEM]);
 		job->requid = slurm_atoul(row[JOB_REQ_KILL_REQUID]);
 		job->qosid = slurm_atoul(row[JOB_REQ_QOS]);
@@ -657,7 +699,9 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 			set = 0;
 			itr = list_iterator_create(job_cond->step_list);
 			while ((selected_step = list_next(itr))) {
-				if (selected_step->jobid != job->jobid) {
+				if ((selected_step->jobid != job->jobid) &&
+				    (selected_step->jobid !=
+				     job->array_job_id)) {
 					continue;
 				} else if (selected_step->stepid == NO_VAL) {
 					job->show_full = 1;
@@ -676,6 +720,11 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 					   selected_step->stepid);
 				set = 1;
 				job->show_full = 0;
+				/* Set it back just in case we are
+				   looking at a job array.
+				*/
+				if (selected_step->stepid == SLURM_BATCH_SCRIPT)
+					selected_step->stepid = INFINITE;
 			}
 			list_iterator_destroy(itr);
 			if (set)
@@ -711,7 +760,7 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 			if (!good_nodes_from_inx(local_cluster_list,
 						 (void **)&curr_cluster,
 						 step_row[STEP_REQ_NODE_INX],
-						 submit))
+						 start))
 				continue;
 
 			step = slurmdb_create_step_rec();
@@ -774,74 +823,76 @@ static int _cluster_get_jobs(mysql_conn_t *mysql_conn,
 			if ((int)step->elapsed < 0)
 				step->elapsed = 0;
 
-			step->user_cpu_sec =
-				slurm_atoul(step_row[STEP_REQ_USER_SEC]);
-			step->user_cpu_usec =
-				slurm_atoul(step_row[STEP_REQ_USER_USEC]);
-			step->sys_cpu_sec =
-				slurm_atoul(step_row[STEP_REQ_SYS_SEC]);
-			step->sys_cpu_usec =
-				slurm_atoul(step_row[STEP_REQ_SYS_USEC]);
-			step->tot_cpu_sec +=
-				step->user_cpu_sec + step->sys_cpu_sec;
-			step->tot_cpu_usec +=
-				step->user_cpu_usec + step->sys_cpu_usec;
-			step->stats.disk_read_max =
-				atof(step_row[STEP_REQ_MAX_DISK_READ]);
-			step->stats.disk_read_max_taskid =
-				slurm_atoul(step_row[
-					STEP_REQ_MAX_DISK_READ_TASK]);
-			step->stats.disk_read_ave =
-				atof(step_row[STEP_REQ_AVE_DISK_READ]);
-			step->stats.disk_write_max =
-				atof(step_row[STEP_REQ_MAX_DISK_WRITE]);
-			step->stats.disk_write_max_taskid =
-				slurm_atoul(step_row[
-					STEP_REQ_MAX_DISK_WRITE_TASK]);
-			step->stats.disk_write_ave =
-				atof(step_row[STEP_REQ_AVE_DISK_WRITE]);
-			step->stats.vsize_max =
-				slurm_atoul(step_row[STEP_REQ_MAX_VSIZE]);
-			step->stats.vsize_max_taskid =
-				slurm_atoul(step_row[STEP_REQ_MAX_VSIZE_TASK]);
-			step->stats.vsize_ave =
-				atof(step_row[STEP_REQ_AVE_VSIZE]);
-			step->stats.rss_max =
-				slurm_atoul(step_row[STEP_REQ_MAX_RSS]);
-			step->stats.rss_max_taskid =
-				slurm_atoul(step_row[STEP_REQ_MAX_RSS_TASK]);
-			step->stats.rss_ave =
-				atof(step_row[STEP_REQ_AVE_RSS]);
-			step->stats.pages_max =
-				slurm_atoul(step_row[STEP_REQ_MAX_PAGES]);
-			step->stats.pages_max_taskid =
-				slurm_atoul(step_row[STEP_REQ_MAX_PAGES_TASK]);
-			step->stats.pages_ave =
-				atof(step_row[STEP_REQ_AVE_PAGES]);
-			step->stats.cpu_min =
-				slurm_atoul(step_row[STEP_REQ_MIN_CPU]);
-			step->stats.cpu_min_taskid =
-				slurm_atoul(step_row[STEP_REQ_MIN_CPU_TASK]);
-			step->stats.cpu_ave = atof(step_row[STEP_REQ_AVE_CPU]);
-			step->stats.act_cpufreq =
-				atof(step_row[STEP_REQ_ACT_CPUFREQ]);
-			step->stats.consumed_energy =
-				atof(step_row[STEP_REQ_CONSUMED_ENERGY]);
 			step->req_cpufreq =
 				slurm_atoul(step_row[STEP_REQ_REQ_CPUFREQ]);
 			step->stepname = xstrdup(step_row[STEP_REQ_NAME]);
 			step->nodes = xstrdup(step_row[STEP_REQ_NODELIST]);
-			step->stats.vsize_max_nodeid =
-				slurm_atoul(step_row[STEP_REQ_MAX_VSIZE_NODE]);
-			step->stats.rss_max_nodeid =
-				slurm_atoul(step_row[STEP_REQ_MAX_RSS_NODE]);
-			step->stats.pages_max_nodeid =
-				slurm_atoul(step_row[STEP_REQ_MAX_PAGES_NODE]);
-			step->stats.cpu_min_nodeid =
-				slurm_atoul(step_row[STEP_REQ_MIN_CPU_NODE]);
-
 			step->requid =
 				slurm_atoul(step_row[STEP_REQ_KILL_REQUID]);
+
+			step->stats.cpu_min = slurm_atoul(
+				step_row[STEP_REQ_MIN_CPU]);
+
+			if (step->stats.cpu_min != NO_VAL) {
+				step->user_cpu_sec = slurm_atoul(
+					step_row[STEP_REQ_USER_SEC]);
+				step->user_cpu_usec = slurm_atoul(
+					step_row[STEP_REQ_USER_USEC]);
+				step->sys_cpu_sec = slurm_atoul(
+					step_row[STEP_REQ_SYS_SEC]);
+				step->sys_cpu_usec = slurm_atoul(
+					step_row[STEP_REQ_SYS_USEC]);
+				step->tot_cpu_sec +=
+					step->user_cpu_sec + step->sys_cpu_sec;
+				step->tot_cpu_usec += step->user_cpu_usec +
+					step->sys_cpu_usec;
+				step->stats.disk_read_max =
+					atof(step_row[STEP_REQ_MAX_DISK_READ]);
+				step->stats.disk_read_max_taskid = slurm_atoul(
+					step_row[STEP_REQ_MAX_DISK_READ_TASK]);
+				step->stats.disk_read_ave =
+					atof(step_row[STEP_REQ_AVE_DISK_READ]);
+				step->stats.disk_write_max =
+					atof(step_row[STEP_REQ_MAX_DISK_WRITE]);
+				step->stats.disk_write_max_taskid = slurm_atoul(
+					step_row[STEP_REQ_MAX_DISK_WRITE_TASK]);
+				step->stats.disk_write_ave =
+					atof(step_row[STEP_REQ_AVE_DISK_WRITE]);
+				step->stats.vsize_max = slurm_atoul(
+					step_row[STEP_REQ_MAX_VSIZE]);
+				step->stats.vsize_max_taskid = slurm_atoul(
+					step_row[STEP_REQ_MAX_VSIZE_TASK]);
+				step->stats.vsize_ave =
+					atof(step_row[STEP_REQ_AVE_VSIZE]);
+				step->stats.rss_max =
+					slurm_atoul(step_row[STEP_REQ_MAX_RSS]);
+				step->stats.rss_max_taskid = slurm_atoul(
+					step_row[STEP_REQ_MAX_RSS_TASK]);
+				step->stats.rss_ave =
+					atof(step_row[STEP_REQ_AVE_RSS]);
+				step->stats.pages_max = slurm_atoul(
+					step_row[STEP_REQ_MAX_PAGES]);
+				step->stats.pages_max_taskid = slurm_atoul(
+					step_row[STEP_REQ_MAX_PAGES_TASK]);
+				step->stats.pages_ave =
+					atof(step_row[STEP_REQ_AVE_PAGES]);
+				step->stats.cpu_min_taskid = slurm_atoul(
+					step_row[STEP_REQ_MIN_CPU_TASK]);
+				step->stats.cpu_ave = atof(
+					step_row[STEP_REQ_AVE_CPU]);
+				step->stats.act_cpufreq =
+					atof(step_row[STEP_REQ_ACT_CPUFREQ]);
+				step->stats.consumed_energy = atof(
+					step_row[STEP_REQ_CONSUMED_ENERGY]);
+				step->stats.vsize_max_nodeid = slurm_atoul(
+					step_row[STEP_REQ_MAX_VSIZE_NODE]);
+				step->stats.rss_max_nodeid = slurm_atoul(
+					step_row[STEP_REQ_MAX_RSS_NODE]);
+				step->stats.pages_max_nodeid = slurm_atoul(
+					step_row[STEP_REQ_MAX_PAGES_NODE]);
+				step->stats.cpu_min_nodeid = slurm_atoul(
+					step_row[STEP_REQ_MIN_CPU_NODE]);
+			}
 		}
 		mysql_free_result(step_result);
 
@@ -956,8 +1007,8 @@ extern List setup_cluster_list_with_inx(mysql_conn_t *mysql_conn,
 			   job_cond->usage_end, job_cond->usage_start);
 	}
 
-	debug3("%d(%s:%d) query\n%s",
-	       mysql_conn->conn, THIS_FILE, __LINE__, query);
+	if (debug_flags & DEBUG_FLAG_DB_JOB)
+		DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 	if (!(result = mysql_db_query_ret(mysql_conn, query, 0))) {
 		xfree(query);
 		goto no_hosts;
@@ -1013,7 +1064,7 @@ no_hosts:
 
 extern int good_nodes_from_inx(List local_cluster_list,
 			       void **object, char *node_inx,
-			       int submit)
+			       int start)
 {
 	local_cluster_t **curr_cluster = (local_cluster_t **)object;
 
@@ -1023,15 +1074,15 @@ extern int good_nodes_from_inx(List local_cluster_list,
 		bitstr_t *job_bitmap = NULL;
 		if (!node_inx || !node_inx[0])
 			return 0;
-		if ((submit < (*curr_cluster)->start)
-		    || (submit > (*curr_cluster)->end)) {
+		if ((start < (*curr_cluster)->start)
+		    || (start > (*curr_cluster)->end)) {
 			local_cluster_t *local_cluster = NULL;
 
 			ListIterator itr =
 				list_iterator_create(local_cluster_list);
 			while ((local_cluster = list_next(itr))) {
-				if ((submit >= local_cluster->start)
-				    && (submit <= local_cluster->end)) {
+				if ((start >= local_cluster->start)
+				    && (start <= local_cluster->end)) {
 					*curr_cluster = local_cluster;
 					break;
 				}
@@ -1155,8 +1206,8 @@ no_resv:
 					   (int)job_cond->usage_end);
 			}
 
-			debug3("%d(%s:%d) query\n%s",
-			       mysql_conn->conn, THIS_FILE, __LINE__, query);
+			if (debug_flags & DEBUG_FLAG_DB_JOB)
+				DB_DEBUG(mysql_conn->conn, "query\n%s", query);
 			result = mysql_db_query_ret(mysql_conn, query, 0);
 			xfree(query);
 			if (!result)
@@ -1332,8 +1383,17 @@ extern int setup_job_cond_limits(mysql_conn_t *mysql_conn,
 		while ((selected_step = list_next(itr))) {
 			if (set)
 				xstrcat(*extra, " || ");
-			xstrfmtcat(*extra, "t1.id_job=%u",
-				   selected_step->jobid);
+			if (selected_step->array_task_id == NO_VAL)
+				xstrfmtcat(*extra, "(t1.id_job=%u || "
+					   "t1.id_array_job=%u)",
+					   selected_step->jobid,
+					   selected_step->jobid);
+			else {
+				xstrfmtcat(*extra, "(t1.id_array_job=%u && "
+					   "t1.id_array_task=%u)",
+					   selected_step->jobid,
+					   selected_step->array_task_id);
+			}
 			set = 1;
 		}
 		list_iterator_destroy(itr);
