@@ -144,8 +144,8 @@ static void *_cluster_rollup_usage(void *arg)
 				"where node_name='' order by "
 				"time_start asc limit 1;",
 				local_rollup->cluster_name, event_table);
-			debug3("%d(%s:%d) query\n%s", mysql_conn.conn,
-			       THIS_FILE, __LINE__, query);
+			if (debug_flags & DEBUG_FLAG_DB_USAGE)
+				DB_DEBUG(mysql_conn.conn, "query\n%s", query);
 			if (!(result = mysql_db_query_ret(
 				      &mysql_conn, query, 0))) {
 				xfree(query);
@@ -172,8 +172,8 @@ static void *_cluster_rollup_usage(void *arg)
 				local_rollup->cluster_name, last_ran_table,
 				lowest, lowest, lowest);
 
-			debug3("%d(%s:%d) query\n%s", mysql_conn.conn,
-			       THIS_FILE, __LINE__, query);
+			if (debug_flags & DEBUG_FLAG_DB_USAGE)
+				DB_DEBUG(mysql_conn.conn, "query\n%s", query);
 			rc = mysql_db_query(&mysql_conn, query);
 			xfree(query);
 			if (rc != SLURM_SUCCESS) {
@@ -372,8 +372,8 @@ static void *_cluster_rollup_usage(void *arg)
 		       local_rollup->cluster_name, month_end, month_start);
 
 	if (query) {
-		debug3("%d(%s:%d) query\n%s",
-		       mysql_conn.conn, THIS_FILE, __LINE__, query);
+		if (debug_flags & DEBUG_FLAG_DB_USAGE)
+			DB_DEBUG(mysql_conn.conn, "query\n%s", query);
 		rc = mysql_db_query(&mysql_conn, query);
 		xfree(query);
 	}
@@ -737,7 +737,6 @@ extern int as_mysql_get_usage(mysql_conn_t *mysql_conn, uid_t uid,
 	char *query = NULL;
 	char *username = NULL;
 	uint16_t private_data = 0;
-	slurmdb_user_rec_t user;
 	List *my_list;
 	uint32_t id = NO_VAL;
 	char *cluster_name = NULL;
@@ -807,17 +806,20 @@ extern int as_mysql_get_usage(mysql_conn_t *mysql_conn, uid_t uid,
 	if (check_connection(mysql_conn) != SLURM_SUCCESS)
 		return ESLURM_DB_CONNECTION;
 
-	memset(&user, 0, sizeof(slurmdb_user_rec_t));
-	user.uid = uid;
-
 	private_data = slurm_get_private_data();
 	if (private_data & PRIVATE_DATA_USAGE) {
 		if (!(is_admin = is_user_min_admin_level(
 			      mysql_conn, uid, SLURMDB_ADMIN_OPERATOR))) {
 			ListIterator itr = NULL;
 			slurmdb_coord_rec_t *coord = NULL;
+			slurmdb_user_rec_t user;
+			bool is_coord;
 
-			if (username && !strcmp(slurmdb_assoc->user, user.name))
+			memset(&user, 0, sizeof(slurmdb_user_rec_t));
+			user.uid = uid;
+			is_coord = is_user_any_coord(mysql_conn, &user);
+
+			if (username && !strcmp(username, user.name))
 				goto is_user;
 
 			if (type != DBD_GET_ASSOC_USAGE)
@@ -829,7 +831,7 @@ extern int as_mysql_get_usage(mysql_conn_t *mysql_conn, uid_t uid,
 				goto bad_user;
 			}
 
-			if (!is_user_any_coord(mysql_conn, &user)) {
+			if (!is_coord) {
 				debug4("This user is not a coordinator.");
 				goto bad_user;
 			}
@@ -924,6 +926,7 @@ extern int as_mysql_roll_usage(mysql_conn_t *mysql_conn,
 {
 	int rc = SLURM_SUCCESS;
 	int rolledup = 0;
+	int roll_started = 0;
 	char *cluster_name = NULL;
 	ListIterator itr;
 	pthread_mutex_t rolledup_lock = PTHREAD_MUTEX_INITIALIZER;
@@ -973,19 +976,24 @@ extern int as_mysql_roll_usage(mysql_conn_t *mysql_conn,
 		 * (millions) of jobs.
 		 */
 		slurm_attr_init(&rollup_attr);
+		if (pthread_attr_setdetachstate(&rollup_attr,
+						PTHREAD_CREATE_DETACHED))
+			error("pthread_attr_setdetachstate error %m");
+
 		if (pthread_create(&rollup_tid, &rollup_attr,
 				   _cluster_rollup_usage,
 				   (void *)local_rollup))
 			fatal("pthread_create: %m");
 		slurm_attr_destroy(&rollup_attr);
+		roll_started++;
 	}
 	slurm_mutex_lock(&rolledup_lock);
 	list_iterator_destroy(itr);
 	slurm_mutex_unlock(&as_mysql_cluster_list_lock);
 
-	while (rolledup < list_count(as_mysql_cluster_list)) {
+	while (rolledup < roll_started) {
 		pthread_cond_wait(&rolledup_cond, &rolledup_lock);
-		debug2("Got %d rolled up", rolledup);
+		debug2("Got %d of %d rolled up", rolledup, roll_started);
 	}
 	slurm_mutex_unlock(&rolledup_lock);
 	debug2("Everything rolled up");
