@@ -116,7 +116,7 @@ typedef struct {
 
 static lustre_sens_t lustre_se = {0,0,0,0,0,0,0,0};
 
-static uint32_t debug_flags = 0;
+static uint64_t debug_flags = 0;
 static pthread_mutex_t lustre_lock = PTHREAD_MUTEX_INITIALIZER;
 
 /* Default path to lustre stats */
@@ -392,7 +392,7 @@ extern void acct_gather_filesystem_p_conf_set(s_p_hashtbl_t *tbl)
 	if (!_run_in_daemon())
 		return;
 
-	verbose("%s loaded", plugin_name);
+	debug("%s loaded", plugin_name);
 }
 
 extern void acct_gather_filesystem_p_conf_options(s_p_options_t **full_options,
