@@ -343,7 +343,7 @@ extern int slurm_ckpt_pack_job(check_jobinfo_t jobinfo, Buf buffer,
 		set_buf_offset(buffer, x);
 		pack32(z - y, buffer);
 		set_buf_offset(buffer, z);
-	} else if (protocol_version >= SLURM_2_5_PROTOCOL_VERSION) {
+	} else if (protocol_version >= SLURM_2_6_PROTOCOL_VERSION) {
 		pack16(check_ptr->disabled, buffer);
 		pack16(check_ptr->node_cnt, buffer);
 		pack16(check_ptr->reply_cnt, buffer);
@@ -383,7 +383,7 @@ extern int slurm_ckpt_unpack_job(check_jobinfo_t jobinfo, Buf buffer,
 					       &uint32_tmp, buffer);
 			safe_unpack_time(&check_ptr->time_stamp, buffer);
 		}
-	} else if (protocol_version >= SLURM_2_5_PROTOCOL_VERSION) {
+	} else if (protocol_version >= SLURM_2_6_PROTOCOL_VERSION) {
 		safe_unpack16(&check_ptr->disabled, buffer);
 		safe_unpack16(&check_ptr->node_cnt, buffer);
 		safe_unpack16(&check_ptr->reply_cnt, buffer);
@@ -417,6 +417,9 @@ static void _send_sig(uint32_t job_id, uint32_t step_id, uint16_t signal,
 {
 	agent_arg_t *agent_args;
 	kill_tasks_msg_t *kill_tasks_msg;
+	uint16_t protocol_version = (uint16_t) NO_VAL;
+	agent_arg_t *agent_arg_ptr;
+	struct node_record *node_ptr;
 
 	kill_tasks_msg = xmalloc(sizeof(kill_tasks_msg_t));
 	kill_tasks_msg->job_id		= job_id;
@@ -430,6 +433,9 @@ static void _send_sig(uint32_t job_id, uint32_t step_id, uint16_t signal,
 	agent_args->hostlist = hostlist_create(node_name);
 	agent_args->node_count		= 1;
 
+	if ((node_ptr = find_node_record(node_name)))
+		agent_args->protocol_version = node_ptr->protocol_version;
+
 	agent_queue_request(agent_args);
 }
 
