@@ -104,8 +104,7 @@ static int _save_state(char *dir_name)
 		error("job_container state directory is NULL");
 		return SLURM_ERROR;
 	}
-	file_name = xstrdup(dir_name);
-	xstrcat(file_name, "/job_container_state");
+	file_name = xstrdup_printf("%s/job_container_state", dir_name);
 	(void) unlink(file_name);
 	state_fd = creat(file_name, 0600);
 	if (state_fd < 0) {
@@ -138,7 +137,7 @@ static int _save_state(char *dir_name)
 
 static int _restore_state(char *dir_name)
 {
-	char *data = NULL, *file_name;
+	char *data = NULL, *file_name = NULL;
 	int error_code = SLURM_SUCCESS;
 	int state_fd, data_allocated = 0, data_read = 0, data_size = 0;
 
@@ -147,8 +146,7 @@ static int _restore_state(char *dir_name)
 		return SLURM_ERROR;
 	}
 
-	file_name = xstrdup(dir_name);
-	xstrcat(file_name, "/job_container_state");
+	file_name = xstrdup_printf("%s/job_container_state", dir_name);
 	state_fd = open (file_name, O_RDONLY);
 	if (state_fd >= 0) {
 		data_allocated = JOB_BUF_SIZE;
@@ -169,7 +167,6 @@ static int _restore_state(char *dir_name)
 			xrealloc(data, data_allocated);
 		}
 		close(state_fd);
-		xfree(file_name);
 	} else {
 		error("No %s file for %s state recovery",
 		      file_name, plugin_type);
@@ -177,6 +174,8 @@ static int _restore_state(char *dir_name)
 		return SLURM_SUCCESS;
 	}
 
+	xfree(file_name);
+
 	if (error_code == SLURM_SUCCESS) {
 		job_id_array = (uint32_t *) data;
 		job_id_count = data_size / sizeof(uint32_t);
@@ -240,7 +239,12 @@ extern int init(void)
  */
 extern int fini(void)
 {
+	slurm_mutex_lock(&context_lock);
 	xfree(state_dir);
+	xfree(job_id_array);
+	job_id_count = 0;
+	slurm_mutex_unlock(&context_lock);
+
 	return SLURM_SUCCESS;
 }
 
@@ -249,8 +253,9 @@ extern int container_p_restore(char *dir_name, bool recover)
 	int i;
 
 	slurm_mutex_lock(&context_lock);
-	_restore_state(dir_name);
-	slurm_mutex_unlock(&context_lock);
+	xfree(state_dir);
+	state_dir = xstrdup(dir_name);
+	_restore_state(state_dir);
 	for (i = 0; i < job_id_count; i++) {
 		if (job_id_array[i] == 0)
 			continue;
@@ -262,9 +267,8 @@ extern int container_p_restore(char *dir_name, bool recover)
 		if (!recover)
 			job_id_array[i] = 0;
 	}
+	slurm_mutex_unlock(&context_lock);
 
-	xfree(state_dir);
-	state_dir = xstrdup(dir_name);
 	return SLURM_SUCCESS;
 }
 
