@@ -225,7 +225,7 @@ extern int fini ( void )
 
 extern int slurm_jobcomp_set_location(char *location)
 {
-	mysql_db_info_t *db_info = create_mysql_db_info(SLURM_MYSQL_PLUGIN_JC);
+	mysql_db_info_t *db_info;
 	int rc = SLURM_SUCCESS;
 	char *db_name = NULL;
 	int i = 0;
@@ -254,6 +254,8 @@ extern int slurm_jobcomp_set_location(char *location)
 	debug2("mysql_connect() called for db %s", db_name);
 	jobcomp_mysql_conn = create_mysql_conn(0, 0, NULL);
 
+	db_info = create_mysql_db_info(SLURM_MYSQL_PLUGIN_JC);
+
 	mysql_db_get_db_connection(jobcomp_mysql_conn, db_name, db_info);
 	xfree(db_name);
 
@@ -271,7 +273,7 @@ extern int slurm_jobcomp_set_location(char *location)
 extern int slurm_jobcomp_log_record(struct job_record *job_ptr)
 {
 	int rc = SLURM_SUCCESS;
-	char *usr_str = NULL, *grp_str = NULL, lim_str[32];
+	char *usr_str = NULL, *grp_str = NULL, lim_str[32], *jname = NULL;
 	char *connect_type = NULL, *reboot = NULL, *rotate = NULL,
 		*geometry = NULL, *start = NULL,
 		*blockid = NULL;
@@ -325,6 +327,11 @@ extern int slurm_jobcomp_log_record(struct job_record *job_ptr)
 		end_time = job_ptr->end_time;
 	}
 
+	if (job_ptr->name && job_ptr->name[0])
+		jname = slurm_add_slash_to_quotes(job_ptr->name);
+	else
+		jname = xstrdup("allocation");
+
 	connect_type = select_g_select_jobinfo_xstrdup(job_ptr->select_jobinfo,
 						       SELECT_PRINT_CONNECTION);
 	reboot = select_g_select_jobinfo_xstrdup(job_ptr->select_jobinfo,
@@ -344,7 +351,7 @@ extern int slurm_jobcomp_log_record(struct job_record *job_ptr)
 #endif
 	query = xstrdup_printf(
 		"insert into %s (jobid, uid, user_name, gid, group_name, "
-		"name, state, proc_cnt, partition, timelimit, "
+		"name, state, proc_cnt, `partition`, timelimit, "
 		"starttime, endtime, nodecnt",
 		jobcomp_table);
 
@@ -364,10 +371,10 @@ extern int slurm_jobcomp_log_record(struct job_record *job_ptr)
 		xstrcat(query, ", start");
 	if (blockid)
 		xstrcat(query, ", blockid");
-	xstrfmtcat(query, ") values (%u, %u, '%s', %u, '%s', \"%s\", %d, %u, "
-		   "'%s', \"%s\", %u, %u, %u",
+	xstrfmtcat(query, ") values (%u, %u, '%s', %u, '%s', '%s', %d, %u, "
+		   "'%s', '%s', %u, %u, %u",
 		   job_ptr->job_id, job_ptr->user_id, usr_str,
-		   job_ptr->group_id, grp_str, job_ptr->name,
+		   job_ptr->group_id, grp_str, jname,
 		   job_state, job_ptr->total_cpus, job_ptr->partition, lim_str,
 		   start_time, end_time, job_ptr->node_cnt);
 
@@ -402,10 +409,12 @@ extern int slurm_jobcomp_log_record(struct job_record *job_ptr)
 		xfree(blockid);
 	}
 	xstrcat(query, ")");
-	//info("query = %s", query);
+	debug3("(%s:%d) query\n%s",
+	       THIS_FILE, __LINE__, query);
 	rc = mysql_db_query(jobcomp_mysql_conn, query);
 	xfree(usr_str);
 	xfree(grp_str);
+	xfree(jname);
 	xfree(query);
 
 	return rc;
