@@ -233,7 +233,8 @@ static void _handle_multi_prog(char *in_file, int *command_pos)
 	FILE *fp;
 	int count = 0;
 
-	if (verify_multi_name(in_file, &opt.ntasks, &opt.ntasks_set))
+	if (verify_multi_name(in_file, &opt.ntasks, &opt.ntasks_set,
+			      &opt.multi_prog_cmds))
 		exit(error_exit);
 
 	fp = fopen(in_file, "r");
@@ -691,20 +692,6 @@ extern int launch_p_create_job_step(srun_job_t *job, bool use_all_cpus,
 				    void (*signal_function)(int),
 				    sig_atomic_t *destroy_job)
 {
-	char value[32];
-
-	/* If srun is call directly this wasn't figured out until
-	   later if the user used --mem.  The problem here is this
-	   will not work with --launch_cmd since that doesn't go get
-	   an actual allocation (which is where pn_min_memory is decided).
-	*/
-	if ((opt.mem_per_cpu == NO_VAL)
-	    && global_resp && (global_resp->pn_min_memory & MEM_PER_CPU)) {
-		snprintf(value, sizeof(value), "%u",
-			 global_resp->pn_min_memory & (~MEM_PER_CPU));
-		setenv("APRUN_DEFAULT_MEMORY", value, 1);
-	}
-
 	if (opt.launch_cmd) {
 		int i = 0;
 		char *cmd_line = NULL;
