@@ -465,15 +465,18 @@ extern int launch_p_create_job_step(srun_job_t *job, bool use_all_cpus,
 				    void (*signal_function)(int),
 				    sig_atomic_t *destroy_job)
 {
+	if (launch_common_create_job_step(job, use_all_cpus,
+					  signal_function,
+					  destroy_job) != SLURM_SUCCESS)
+		return SLURM_ERROR;
+
 	/* set the jobid for totalview */
 	totalview_jobid = NULL;
 	xstrfmtcat(totalview_jobid, "%u", job->jobid);
 	totalview_stepid = NULL;
 	xstrfmtcat(totalview_stepid, "%u", job->stepid);
 
-	return launch_common_create_job_step(job, use_all_cpus,
-					     signal_function,
-					     destroy_job);
+	return SLURM_SUCCESS;
 }
 
 static char **_build_user_env(void)
