@@ -305,6 +305,7 @@ _setup_stepd_kvs(const stepd_step_rec_t *job, char ***env)
 	int rc = SLURM_SUCCESS, i = 0, pp_cnt = 0;
 	char *p, env_key[32], *ppkey, *ppval;
 
+	kvs_seq = 1;
 	rc = temp_kvs_init();
 	if (rc != SLURM_SUCCESS)
 		return rc;
@@ -457,7 +458,8 @@ _get_proc_mapping(const mpi_plugin_client_info_t *job)
 				}
 				if (start_id >= node_cnt)
 					break;
-				/* find start block. block may be less than plane size */
+				/* find start block. block may be less
+				 * than plane size */
 				block = 0;
 				while (rounds[start_id] < tasks[start_id] &&
 				       (task_mapped ==
@@ -471,9 +473,12 @@ _get_proc_mapping(const mpi_plugin_client_info_t *job)
 				while (end_id < node_cnt &&
 				       (rounds[end_id] + block - 1 <
 					tasks[end_id])) {
-					for (i = 0; i < tasks[end_id] - rounds[end_id]; i ++) {
+					for (i = 0;
+					     i < tasks[end_id] - rounds[end_id];
+					     i ++) {
 						if (task_mapped + i !=
-						    tids[end_id][rounds[end_id] + i]) {
+						    tids[end_id][rounds[end_id]
+								 + i]) {
 							break;
 						}
 					}
@@ -498,12 +503,12 @@ _get_proc_mapping(const mpi_plugin_client_info_t *job)
 		for (i = start_id + 1; i < node_cnt; i ++) {
 			if (node_task_cnt == tasks[i])
 				continue;
-			xstrfmtcat(mapping, ",(%u,%u,%hu)", start_id,
+			xstrfmtcat(mapping, ",(%u,%u,%u)", start_id,
 				   i - start_id, node_task_cnt);
 			start_id = i;
 			node_task_cnt = tasks[i];
 		}
-		xstrfmtcat(mapping, ",(%u,%u,%hu))", start_id, i - start_id,
+		xstrfmtcat(mapping, ",(%u,%u,%u))", start_id, i - start_id,
 			   node_task_cnt);
 	}
 
@@ -625,7 +630,7 @@ static int
 _setup_srun_socket(const mpi_plugin_client_info_t *job)
 {
 	if (net_stream_listen(&tree_sock,
-			      (short int *)&tree_info.pmi_port) < 0) {
+			      &tree_info.pmi_port) < 0) {
 		error("mpi/pmi2: Failed to create tree socket");
 		return SLURM_ERROR;
 	}
@@ -639,6 +644,7 @@ _setup_srun_kvs(const mpi_plugin_client_info_t *job)
 {
 	int rc;
 
+	kvs_seq = 1;
 	rc = temp_kvs_init();
 	return rc;
 }
