@@ -45,30 +45,19 @@
 #include <inttypes.h>
 #endif
 
-#if defined(__NetBSD__)
-#include <sys/types.h> /* for pid_t */
-#include <sys/signal.h> /* for SIGKILL */
-#endif
-
-#if defined(__FreeBSD__)
-#include <signal.h>
-#endif
-
 #include "slurm/slurm.h"
 #include "slurm/slurm_errno.h"
 #include "src/common/log.h"
-#include "src/slurmd/slurmd/slurmd.h"
-
-#include "src/slurmd/slurmstepd/slurmstepd_job.h"
-
 #include "src/common/xcgroup_read_config.h"
-#include "src/common/xcgroup.h"
 #include "src/common/xstring.h"
-#include "src/common/xcpuinfo.h"
+#include "src/slurmd/slurmd/slurmd.h"
+#include "src/slurmd/slurmstepd/slurmstepd_job.h"
+#include "src/slurmd/common/xcgroup.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <signal.h>
 #include <stdlib.h>
 
 /*
@@ -207,7 +196,7 @@ int _slurm_cgroup_create(stepd_step_rec_t *job, uint64_t id, uid_t uid, gid_t gi
 
 	/* build job step cgroup relative path (should not be) */
 	if (*jobstep_cgroup_path == '\0') {
-		if (job->stepid == NO_VAL) {
+		if (job->stepid == SLURM_BATCH_SCRIPT) {
 			if (snprintf(jobstep_cgroup_path, PATH_MAX,
 				     "%s/step_batch", job_cgroup_path)
 			    >= PATH_MAX) {
@@ -285,7 +274,7 @@ int _slurm_cgroup_destroy(void)
 
 	if (jobstep_cgroup_path[0] != '\0') {
 		if (xcgroup_delete(&step_freezer_cg) != XCGROUP_SUCCESS) {
-			error("_slurm_cgroup_destroy: problem deleting step "
+			debug("_slurm_cgroup_destroy: problem deleting step "
 			      "cgroup path %s: %m", step_freezer_cg.path);
 			xcgroup_unlock(&freezer_cg);
 			return SLURM_ERROR;
