@@ -1154,8 +1154,14 @@ try_again:
 		 * only used for sub-block jobs we only create it
 		 * when needed. */
 		if (!ba_mp->cnode_bitmap)
+		if (!ba_mp->cnode_bitmap) {
 			ba_mp->cnode_bitmap =
 				ba_create_ba_mp_cnode_bitmap(bg_record);
+			FREE_NULL_BITMAP(ba_mp->cnode_usable_bitmap);
+			ba_mp->cnode_usable_bitmap =
+				bit_copy(ba_mp->cnode_bitmap);
+		}
+
 		if (!ba_mp->cnode_err_bitmap)
 			ba_mp->cnode_err_bitmap =
 				bit_alloc(bg_conf->mp_cnode_cnt);
@@ -1445,10 +1451,15 @@ extern void ba_sync_job_to_block(bg_record_t *bg_record,
 			while ((ba_mp = list_next(ba_itr))) {
 				if (node_inx != ba_mp->index)
 					continue;
-				if (!ba_mp->cnode_bitmap)
+				if (!ba_mp->cnode_bitmap) {
 					ba_mp->cnode_bitmap =
 						ba_create_ba_mp_cnode_bitmap(
 							bg_record);
+					FREE_NULL_BITMAP(
+						ba_mp->cnode_usable_bitmap);
+					ba_mp->cnode_usable_bitmap =
+						bit_copy(ba_mp->cnode_bitmap);
+				}
 				if (!ba_mp->cnode_err_bitmap)
 					ba_mp->cnode_err_bitmap = bit_alloc(
 						bg_conf->mp_cnode_cnt);
@@ -1473,7 +1484,7 @@ extern void ba_sync_job_to_block(bg_record_t *bg_record,
 extern bitstr_t *ba_create_ba_mp_cnode_bitmap(bg_record_t *bg_record)
 {
 	int start, end, ionode_num;
-	char *tmp_char, *tmp_char2;
+	char *tmp_char = NULL, *tmp_char2;
 	bitstr_t *cnode_bitmap = bit_alloc(bg_conf->mp_cnode_cnt);
 
 	if (!bg_record->ionode_bitmap
@@ -1489,10 +1500,11 @@ extern bitstr_t *ba_create_ba_mp_cnode_bitmap(bg_record_t *bg_record)
 		nc_start = ionode_num * (int)bg_conf->nc_ratio;
 		nc_end = nc_start + (int)bg_conf->nc_ratio;
 		for (nc_num = nc_start; nc_num < nc_end; nc_num++)
-			ba_node_map_set_range(cnode_bitmap,
-					      g_nc_coords[nc_num].start,
-					      g_nc_coords[nc_num].end,
-					      ba_mp_geo_system);
+			/* this should always be true */
+			(void)ba_node_map_set_range(cnode_bitmap,
+						    g_nc_coords[nc_num].start,
+						    g_nc_coords[nc_num].end,
+						    ba_mp_geo_system);
 	}
 
 	if (ba_debug_flags & DEBUG_FLAG_BG_ALGO_DEEP)
@@ -1513,6 +1525,64 @@ extern bitstr_t *ba_create_ba_mp_cnode_bitmap(bg_record_t *bg_record)
 	return cnode_bitmap;
 }
 
+extern bitstr_t *ba_cnodelist2bitmap(char *cnodelist)
+{
+	char *cnode_name;
+	hostlist_t hl;
+	bitstr_t *cnode_bitmap = bit_alloc(bg_conf->mp_cnode_cnt);
+	int coord[ba_mp_geo_system->dim_count], dim = 0;
+
+	if (!cnodelist)
+		return cnode_bitmap;
+
+	if (!(hl = hostlist_create_dims(
+		      cnodelist, ba_mp_geo_system->dim_count))) {
+		FREE_NULL_BITMAP(cnode_bitmap);
+		error("ba_cnodelist2bitmap: couldn't create a hotlist from "
+		      "cnodelist given %s", cnodelist);
+		return NULL;
+	}
+
+	while ((cnode_name = hostlist_shift_dims(
+			hl, ba_mp_geo_system->dim_count))) {
+		for (dim = 0; dim < ba_mp_geo_system->dim_count; dim++) {
+			if (!cnode_name[dim])
+				break;
+			coord[dim] = select_char2coord(cnode_name[dim]);
+		}
+		free(cnode_name);
+
+		if (dim != ba_mp_geo_system->dim_count)
+			break;
+
+		if (ba_node_map_set_range(cnode_bitmap, coord, coord,
+					  ba_mp_geo_system) == -1) {
+			/* failure */
+			dim = 0;
+			break;
+		}
+	}
+	hostlist_destroy(hl);
+
+	if (dim != ba_mp_geo_system->dim_count) {
+		FREE_NULL_BITMAP(cnode_bitmap);
+		error("ba_cnodelist2bitmap: bad cnodelist given %s", cnodelist);
+		return NULL;
+	}
+
+	bit_not(cnode_bitmap);
+
+	if (ba_debug_flags & DEBUG_FLAG_BG_ALGO_DEEP) {
+		char *tmp_char = ba_node_map_ranged_hostlist(cnode_bitmap,
+							     ba_mp_geo_system);
+		info("ba_cnodelist2bitmap: %s translates to %s inverted",
+		     cnodelist, tmp_char);
+		xfree(tmp_char);
+	}
+
+	return cnode_bitmap;
+}
+
 extern void ba_set_ionode_str(bg_record_t *bg_record)
 {
 	int ionode_num, coords[5];
@@ -1953,7 +2023,6 @@ static int _fill_in_wires(List mps, ba_mp_t *start_mp, int dim,
 		     ba_switch_usage_str(start_mp->axis_switch[dim].usage),
 		     ba_switch_usage_str(start_mp->alter_switch[dim].usage));
 
-	axis_switch = &start_mp->axis_switch[dim];
 	alter_switch = &start_mp->alter_switch[dim];
 
 	if (_mp_out_used(start_mp, dim))
@@ -2063,7 +2132,9 @@ static int _fill_in_wires(List mps, ba_mp_t *start_mp, int dim,
 			}
 		} else {
 			/* we can't use this so return with a nice 0 */
-			info("_fill_in_wires: we can't use this so return");
+			if (ba_debug_flags & DEBUG_FLAG_BG_ALGO_DEEP)
+				info("_fill_in_wires: we can't use this "
+				     "so return");
 			return 0;
 		}
 
