@@ -337,9 +337,12 @@ extern void bg_requeue_job(uint32_t job_id, bool wait_for_start,
 
 	if (!slurmctld_locked)
 		lock_slurmctld(job_write_lock);
-	if ((rc = job_requeue(0, job_id, -1, (uint16_t)NO_VAL, preempted))) {
-		error("Couldn't requeue job %u, failing it: %s",
-		      job_id, slurm_strerror(rc));
+	rc = job_requeue(0, job_id, -1, (uint16_t)NO_VAL, preempted, 0);
+	if (rc == ESLURM_JOB_PENDING) {
+		error("%s: Could not requeue pending job %u", __func__, job_id);
+	} else if (rc != SLURM_SUCCESS) {
+		error("%s: Could not requeue job %u, failing it: %s",
+		      __func__, job_id, slurm_strerror(rc));
 		job_fail(job_id, job_state);
 	}
 	if (!slurmctld_locked)
