@@ -277,6 +277,15 @@ unpack_error:
 	return SLURM_ERROR;
 }
 
+static int _update_job(job_desc_msg_t * job_specs, uid_t uid)
+{
+	slurm_msg_t msg;
+
+	msg.data= job_specs;
+	msg.conn_fd = -1;
+	return update_job(&msg, uid);
+}
+
 /*
  * Save all nonstop plugin state information
  */
@@ -370,12 +379,12 @@ extern int save_nonstop_state(void)
 extern int restore_nonstop_state(void)
 {
 	char *dir_path, *state_file;
-	uint32_t data_allocated, data_size = 0, data_read;
+	uint32_t data_allocated, data_size = 0;
 	uint32_t job_cnt = 0;
 	char *data;
 	uint16_t protocol_version = (uint16_t) NO_VAL;
-	Buf buffer = init_buf(0);
-	int error_code = SLURM_SUCCESS, i, state_fd;
+	Buf buffer;
+	int error_code = SLURM_SUCCESS, i, state_fd, data_read;
 	time_t buf_time;
 	job_failures_t *job_fail_ptr = NULL;
 
@@ -1057,7 +1066,7 @@ extern char *drop_node(char *cmd_ptr, uid_t cmd_uid,
 		job_alloc_req.job_id	= job_id;
 		job_alloc_req.req_nodes	= hostlist_ranged_string_xmalloc(hl);
 		hostlist_destroy(hl);
-		rc = update_job(&job_alloc_req, cmd_uid);
+		rc = _update_job(&job_alloc_req, cmd_uid);
 		if (rc) {
 			info("slurmctld/nonstop: can remove failing node %s "
 			     "from job %u: %s",
@@ -1276,11 +1285,13 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 			  1,			/* allocate */
 			  cmd_uid,		/* submit UID */
 			  &new_job_ptr,		/* pointer to new job */
-			  NULL);		/* error message */
+			  NULL,                 /* error message */
+			  SLURM_PROTOCOL_VERSION);
 	if (rc != SLURM_SUCCESS) {
 		/* Determine expected start time */
 		i = job_allocate(&job_alloc_req, 1, 1, &will_run, 1,
-				 cmd_uid, &new_job_ptr, NULL);
+				 cmd_uid, &new_job_ptr, NULL,
+				 SLURM_PROTOCOL_VERSION);
 		if (i == SLURM_SUCCESS) {
 			will_run_idle = will_run->start_time;
 			slurm_free_will_run_response_msg(will_run);
@@ -1300,12 +1311,14 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 			(void) update_resv(&resv_desc);
 			xfree(resv_desc.users);
 			rc = job_allocate(&job_alloc_req, 1, 0,	NULL, 1,
-					  cmd_uid, &new_job_ptr, NULL);
+					  cmd_uid, &new_job_ptr, NULL,
+					  SLURM_PROTOCOL_VERSION);
 			if (rc != SLURM_SUCCESS) {
 				/* Determine expected start time */
 				i = job_allocate(&job_alloc_req, 1, 1,
 						 &will_run, 1, cmd_uid,
-						 &new_job_ptr, NULL);
+						 &new_job_ptr, NULL,
+						 SLURM_PROTOCOL_VERSION);
 				if (i == SLURM_SUCCESS) {
 					will_run_resv = will_run->start_time;
 					slurm_free_will_run_response_msg(
@@ -1315,7 +1328,8 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 					/* Submit job in resv for later use */
 					i = job_allocate(&job_alloc_req, 0, 0,
 							 NULL, 1, cmd_uid,
-							 &new_job_ptr, NULL);
+							 &new_job_ptr, NULL,
+							 SLURM_PROTOCOL_VERSION);
 					if (i == SLURM_SUCCESS)
 						will_run_time = will_run_resv;
 				}
@@ -1330,7 +1344,7 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 	if ((rc != SLURM_SUCCESS) && (will_run_time == 0) && will_run_idle) {
 		/* Submit job for later use without using reservation */
 		i = job_allocate(&job_alloc_req, 0, 0, NULL, 1, cmd_uid,
-				 &new_job_ptr, NULL);
+				 &new_job_ptr, NULL, SLURM_PROTOCOL_VERSION);
 		if (i == SLURM_SUCCESS)
 			will_run_time = will_run_idle;
 	}
@@ -1376,13 +1390,18 @@ extern char *replace_node(char *cmd_ptr, uid_t cmd_uid,
 	xfree(job_alloc_req.reservation);
 	xfree(job_alloc_req.wckey);
 
-merge:	new_node_name = strdup(new_job_ptr->nodes);
+merge:
+	if (!new_job_ptr) {	/* Fix for CLANG false positive */
+		error("%s: New job is NULL", __func__);
+		return resp;
+	}
+	new_node_name = strdup(new_job_ptr->nodes);
 
 	/* Shrink the size of the new job to zero */
 	slurm_init_job_desc_msg(&job_alloc_req);
 	job_alloc_req.job_id	= new_job_ptr->job_id;
 	job_alloc_req.min_nodes	= 0;
-	rc = update_job(&job_alloc_req, cmd_uid);
+	rc = _update_job(&job_alloc_req, cmd_uid);
 
 	/* Without unlock, the job_fini_callback() function will deadlock.
 	 * Not a great solution, but perhaps the least bad solution. */
@@ -1405,7 +1424,7 @@ merge:	new_node_name = strdup(new_job_ptr->nodes);
 	slurm_init_job_desc_msg(&job_alloc_req);
 	job_alloc_req.job_id	= job_id;
 	job_alloc_req.min_nodes	= INFINITE;
-	rc = update_job(&job_alloc_req, cmd_uid);
+	rc = _update_job(&job_alloc_req, cmd_uid);
 	if (rc) {
 		info("slurmctld/nonstop: can not grow job %u: %s",
 		     job_id, slurm_strerror(rc));
@@ -1441,7 +1460,7 @@ merge:	new_node_name = strdup(new_job_ptr->nodes);
 		job_alloc_req.job_id	= job_id;
 		job_alloc_req.req_nodes	= hostlist_ranged_string_xmalloc(hl);
 		hostlist_destroy(hl);
-		rc = update_job(&job_alloc_req, cmd_uid);
+		rc = _update_job(&job_alloc_req, cmd_uid);
 		if (rc) {
 			info("slurmctld/nonstop: can remove failing node %s "
 			     "from job %u: %s",
@@ -1674,7 +1693,7 @@ extern char *time_incr(char *cmd_ptr, uid_t cmd_uid, uint32_t protocol_version)
 		job_specs.job_id = job_id;
 		job_specs.time_limit  = job_fail_ptr->job_ptr->time_limit;
 		job_specs.time_limit += minutes;
-		rc = update_job(&job_specs, cmd_uid);
+		rc = _update_job(&job_specs, cmd_uid);
 	}
 	if (rc) {
 		xstrfmtcat(resp, "%s EJOBUPDATE %s", SLURM_VERSION_STRING,
