@@ -264,6 +264,88 @@ void batch_bind(batch_job_launch_msg_t *req)
 	slurm_cred_free_args(&arg);
 }
 
+/* The job has specialized cores, synchronize user map with available cores */
+static void _validate_map(launch_tasks_request_msg_t *req, char *avail_mask)
+{
+	char *tmp_map, *save_ptr = NULL, *tok;
+	cpu_set_t avail_cpus;
+	bool superset = true;
+
+	CPU_ZERO(&avail_cpus);
+	(void) str_to_cpuset(&avail_cpus, avail_mask);
+	tmp_map = xstrdup(req->cpu_bind);
+	tok = strtok_r(tmp_map, ",", &save_ptr);
+	while (tok) {
+		int i = atoi(tok);
+		if (!CPU_ISSET(i, &avail_cpus)) {
+			/* The task's CPU map is completely invalid.
+			 * Disable CPU map. */
+			superset = false;
+			break;
+		}
+		tok = strtok_r(NULL, ",", &save_ptr);
+	}
+	xfree(tmp_map);
+
+	if (!superset) {
+		info("task/affinity: Ignoring user CPU binding outside of job "
+		     "step allocation");
+		req->cpu_bind_type &= (~CPU_BIND_MAP);
+		req->cpu_bind_type |=   CPU_BIND_MASK;
+		xfree(req->cpu_bind);
+		req->cpu_bind = xstrdup(avail_mask);
+	}
+}
+
+/* The job has specialized cores, synchronize user mask with available cores */
+static void _validate_mask(launch_tasks_request_msg_t *req, char *avail_mask)
+{
+	char *new_mask = NULL, *save_ptr = NULL, *tok;
+	cpu_set_t avail_cpus, task_cpus;
+	bool superset = true;
+
+	CPU_ZERO(&avail_cpus);
+	(void) str_to_cpuset(&avail_cpus, avail_mask);
+	tok = strtok_r(req->cpu_bind, ",", &save_ptr);
+	while (tok) {
+		int i, overlaps = 0;
+		char mask_str[1 + CPU_SETSIZE / 4];
+		CPU_ZERO(&task_cpus);
+		(void) str_to_cpuset(&task_cpus, tok);
+		for (i = 0; i < CPU_SETSIZE; i++) {
+			if (!CPU_ISSET(i, &task_cpus))
+				continue;
+			if (CPU_ISSET(i, &avail_cpus)) {
+				overlaps++;
+			} else {
+				CPU_CLR(i, &task_cpus);
+				superset = false;
+			}
+		}
+		if (overlaps == 0) {
+			/* The task's CPU mask is completely invalid.
+			 * Give it all allowed CPUs. */
+			for (i = 0; i < CPU_SETSIZE; i++) {
+				if (CPU_ISSET(i, &avail_cpus))
+					CPU_SET(i, &task_cpus);
+			}
+		}
+		cpuset_to_str(&task_cpus, mask_str);
+		if (new_mask)
+			xstrcat(new_mask, ",");
+		xstrcat(new_mask, mask_str);
+		tok = strtok_r(NULL, ",", &save_ptr);
+	}
+
+	if (!superset) {
+		info("task/affinity: Ignoring user CPU binding outside of job "
+		     "step allocation");
+	}
+
+	xfree(req->cpu_bind);
+	req->cpu_bind = new_mask;
+}
+
 /*
  * lllp_distribution
  *
@@ -295,6 +377,21 @@ void lllp_distribution(launch_tasks_request_msg_t *req, uint32_t node_id)
 				    CPU_BIND_RANK   | CPU_BIND_MAP    |
 				    CPU_BIND_LDMASK | CPU_BIND_LDRANK |
 				    CPU_BIND_LDMAP;
+	static int only_one_thread_per_core = -1;
+
+	if (only_one_thread_per_core == -1) {
+		if (conf->cpus == (conf->sockets * conf->cores))
+			only_one_thread_per_core = 1;
+		else
+			only_one_thread_per_core = 0;
+	}
+
+	/* If we are telling the system we only want to use 1 thread
+	 * per core with the CPUs node option this is the easiest way
+	 * to portray that to the affinity plugin.
+	 */
+	if (only_one_thread_per_core)
+		req->cpu_bind_type |= CPU_BIND_ONE_THREAD_PER_CORE;
 
 	if (req->cpu_bind_type & bind_mode) {
 		/* Explicit step binding specified by user */
@@ -302,16 +399,21 @@ void lllp_distribution(launch_tasks_request_msg_t *req, uint32_t node_id)
 					       &whole_nodes,  &whole_sockets,
 					       &whole_cores,  &whole_threads,
 					       &part_sockets, &part_cores);
-		if ((whole_nodes == 0) && avail_mask) {
-			/* Step does NOT have access to whole node,
-			 * bind to full mask of available processors */
+		if ((whole_nodes == 0) && avail_mask &&
+		    (req->job_core_spec == (uint16_t) NO_VAL)) {
+			info("task/affinity: entire node must be allocated, "
+			     "disabling affinity");
 			xfree(req->cpu_bind);
 			req->cpu_bind = avail_mask;
 			req->cpu_bind_type &= (~bind_mode);
 			req->cpu_bind_type |= CPU_BIND_MASK;
 		} else {
-			/* Step does have access to whole node,
-			 * bind to whatever step wants */
+			if (req->job_core_spec == (uint16_t) NO_VAL) {
+				if (req->cpu_bind_type & CPU_BIND_MASK)
+					_validate_mask(req, avail_mask);
+				else if (req->cpu_bind_type & CPU_BIND_MAP)
+					_validate_map(req, avail_mask);
+			}
 			xfree(avail_mask);
 		}
 		slurm_sprint_cpu_bind_type(buf_type, req->cpu_bind_type);
@@ -323,7 +425,10 @@ void lllp_distribution(launch_tasks_request_msg_t *req, uint32_t node_id)
 	if (!(req->cpu_bind_type & bind_entity)) {
 		/* No bind unit (sockets, cores) specified by user,
 		 * pick something reasonable */
-		int max_tasks = req->tasks_to_launch[(int)node_id];
+		uint16_t task_plugin_param = slurm_get_task_plugin_param();
+		bool auto_def_set = false;
+		int max_tasks = req->tasks_to_launch[(int)node_id] *
+			req->cpus_per_task;
 		char *avail_mask = _alloc_mask(req,
 					       &whole_nodes,  &whole_sockets,
 					       &whole_cores,  &whole_threads,
@@ -345,11 +450,19 @@ void lllp_distribution(launch_tasks_request_msg_t *req, uint32_t node_id)
 			req->cpu_bind_type |= CPU_BIND_TO_THREADS;
 			goto make_auto;
 		}
+
+		if (task_plugin_param & CPU_AUTO_BIND_TO_THREADS) {
+			auto_def_set = true;
+			req->cpu_bind_type |= CPU_BIND_TO_THREADS;
+			goto make_auto;
+		}
+
 		if (avail_mask) {
 			xfree(req->cpu_bind);
 			req->cpu_bind = avail_mask;
 			req->cpu_bind_type |= CPU_BIND_MASK;
 		}
+
 		slurm_sprint_cpu_bind_type(buf_type, req->cpu_bind_type);
 		info("lllp_distribution jobid [%u] auto binding off: %s",
 		     req->job_id, buf_type);
@@ -357,8 +470,10 @@ void lllp_distribution(launch_tasks_request_msg_t *req, uint32_t node_id)
 
   make_auto:	xfree(avail_mask);
 		slurm_sprint_cpu_bind_type(buf_type, req->cpu_bind_type);
-		info("lllp_distribution jobid [%u] implicit auto binding: "
-		     "%s, dist %d", req->job_id, buf_type, req->task_dist);
+		info("lllp_distribution jobid [%u] %s auto binding: "
+		     "%s, dist %d", req->job_id,
+		     (auto_def_set) ? "default" : "implicit",
+		     buf_type, req->task_dist);
 	} else {
 		/* Explicit bind unit (sockets, cores) specified by user */
 		slurm_sprint_cpu_bind_type(buf_type, req->cpu_bind_type);
@@ -847,6 +962,27 @@ static int _task_layout_lllp_cyclic(launch_tasks_request_msg_t *req,
 
 			if (++p < req->cpus_per_task)
 				continue;
+
+			/* Means we are binding to cores so skip the
+			   rest of the threads in this one.  If a user
+			   requests ntasks-per-core=1 and the
+			   cpu_bind=threads this will not be able to
+			   work since we don't know how many tasks per
+			   core have been allocated.
+			*/
+			if (!(req->cpu_bind_type & CPU_BIND_ONE_THREAD_PER_CORE)
+			    && ((req->cpu_bind_type & CPU_BIND_TO_CORES)
+				|| (slurm_get_select_type_param() &
+				    CR_ONE_TASK_PER_CORE))) {
+				int threads_not_used;
+				if (req->cpus_per_task < hw_threads)
+					threads_not_used =
+						hw_threads - req->cpus_per_task;
+				else
+					threads_not_used =
+						req->cpus_per_task % hw_threads;
+				socket_last_pu[s] += threads_not_used;
+			}
 			p = 0;
 
 			if (!already_switched) {
@@ -955,6 +1091,26 @@ static int _task_layout_lllp_block(launch_tasks_request_msg_t *req,
 
 			if (++c < req->cpus_per_task)
 				continue;
+			/* Means we are binding to cores so skip the
+			   rest of the threads in this one.  If a user
+			   requests ntasks-per-core=1 and the
+			   cpu_bind=threads this will not be able to
+			   work since we don't know how many tasks per
+			   core have been allocated.
+			*/
+			if (!(req->cpu_bind_type & CPU_BIND_ONE_THREAD_PER_CORE)
+			    && ((req->cpu_bind_type & CPU_BIND_TO_CORES)
+				|| (slurm_get_select_type_param() &
+				    CR_ONE_TASK_PER_CORE))) {
+				int threads_not_used;
+				if (req->cpus_per_task < hw_threads)
+					threads_not_used =
+						hw_threads - req->cpus_per_task;
+				else
+					threads_not_used =
+						req->cpus_per_task % hw_threads;
+				i += threads_not_used;
+			}
 			c = 0;
 			if (++taskcount >= max_tasks)
 				break;
