@@ -44,11 +44,14 @@
 
 #include "slurm/slurm_errno.h"
 #include "src/common/slurm_xlator.h"
-#include "src/slurmd/slurmstepd/slurmstepd_job.h"
-#include "src/slurmd/slurmd/slurmd.h"
-#include "src/common/xcgroup.h"
-#include "src/common/xstring.h"
 #include "src/common/xcgroup_read_config.h"
+#include "src/common/xstring.h"
+
+#include "src/slurmd/slurmstepd/slurmstepd_job.h"
+
+#include "src/slurmd/slurmd/slurmd.h"
+
+#include "src/slurmd/common/xcgroup.h"
 
 #include "task_cgroup.h"
 #include "task_cgroup_cpuset.h"
@@ -134,7 +137,7 @@ extern int init (void)
 		      plugin_type);
 	}
 
-	verbose("%s: loaded", plugin_type);
+	debug("%s: loaded", plugin_type);
 	return SLURM_SUCCESS;
 }
 
