@@ -197,7 +197,7 @@ static print_field_t *_get_print_field(char *object)
 		field->print_routine = print_fields_uint16;
 	} else if (!strncasecmp("Classification", object,
 				MAX(command_len, 3))) {
-		field->type = PRINT_CPUS;
+		field->type = PRINT_CLASS;
 		field->name = xstrdup("Class");
 		field->len = 9;
 		field->print_routine = print_fields_str;
@@ -353,9 +353,9 @@ static print_field_t *_get_print_field(char *object)
 		field->name = xstrdup("LFT");
 		field->len = 6;
 		field->print_routine = print_fields_uint;
-	} else if (!strncasecmp("Manager", object, MAX(command_len, 3))) {
-		field->type = PRINT_MANAGER;
-		field->name = xstrdup("Manager");
+	} else if (!strncasecmp("servertype", object, MAX(command_len, 10))) {
+		field->type = PRINT_SERVERTYPE;
+		field->name = xstrdup("ServerType");
 		field->len = 10;
 		field->print_routine = print_fields_str;
 	} else if (!strncasecmp("MaxCPUMinsPerJob", object,
@@ -421,6 +421,11 @@ static print_field_t *_get_print_field(char *object)
 		field->name = xstrdup("MaxWall");
 		field->len = 11;
 		field->print_routine = print_fields_time;
+	} else if (!strncasecmp("MinCPUsPerJob", object, MAX(command_len, 7))) {
+		field->type = PRINT_MINC;
+		field->name = xstrdup("MinCPUs");
+		field->len = 8;
+		field->print_routine = print_fields_uint;
 	} else if (!strncasecmp("Name", object, MAX(command_len, 2))) {
 		field->type = PRINT_NAME;
 		field->name = xstrdup("Name");
@@ -535,10 +540,10 @@ static print_field_t *_get_print_field(char *object)
 		field->name = xstrdup("UsageThres");
 		field->len = 10;
 		field->print_routine = print_fields_double;
-	} else if (!strncasecmp("Used", object, MAX(command_len, 7))) {
-		field->type = PRINT_USED;
-		field->name = xstrdup("% Used");
-		field->len = 10;
+	} else if (!strncasecmp("Allocated", object, MAX(command_len, 7))) {
+		field->type = PRINT_ALLOCATED;
+		field->name = xstrdup("% Allocated");
+		field->len = 11;
 		field->print_routine = print_fields_uint16;
 	} else if (!strncasecmp("User", object, MAX(command_len, 1))) {
 		field->type = PRINT_USER;
@@ -1691,6 +1696,11 @@ extern void sacctmgr_print_qos_limits(slurmdb_qos_rec_t *qos)
 		printf("  MaxWall        = %s\n", time_buf);
 	}
 
+	if (qos->min_cpus_pj == INFINITE)
+		printf("  MinCPUs        = NONE\n");
+	else if (qos->min_cpus_pj != NO_VAL)
+		printf("  MinCPUs        = %u\n", qos->min_cpus_pj);
+
 	if (qos->preempt_list) {
 		char *temp_char = get_qos_complete_str(g_qos_list,
 						       qos->preempt_list);
