@@ -1935,7 +1935,8 @@ extern void load_sacctmgr_cfg_file (int argc, char *argv[])
 	xfree(file_name);
 	if (fd == NULL) {
 		exit_code=1;
-		fprintf(stderr, " Unable to read \"%s\": %m\n", argv[0]);
+		fprintf(stderr, " Unable to read \"%s\": %s\n", argv[0],
+			slurm_strerror(errno));
 		xfree(cluster_name);
 		return;
 	}
@@ -2038,7 +2039,7 @@ extern void load_sacctmgr_cfg_file (int argc, char *argv[])
 			assoc_cond.only_defs = 0;
 
 			/* make sure this person running is an admin */
-			user_name = uid_to_string(my_uid);
+			user_name = uid_to_string_cached(my_uid);
 			if (!(user = sacctmgr_find_user_from_list(
 				      curr_user_list, user_name))) {
 				exit_code=1;
@@ -2047,7 +2048,6 @@ extern void load_sacctmgr_cfg_file (int argc, char *argv[])
 					my_uid);
 				if (curr_user_list)
 					list_destroy(curr_user_list);
-				xfree(user_name);
 				return;
 
 			} else {
@@ -2062,7 +2062,6 @@ extern void load_sacctmgr_cfg_file (int argc, char *argv[])
 						"privileges to load files.\n");
 					if (curr_user_list)
 						list_destroy(curr_user_list);
-					xfree(user_name);
 					return;
 				}
 			}
@@ -2135,7 +2134,7 @@ extern void load_sacctmgr_cfg_file (int argc, char *argv[])
 				list_append(temp_assoc_list,
 					    cluster->root_assoc);
 
-				rc = _print_out_assoc(temp_assoc_list, 0, 0);
+				(void) _print_out_assoc(temp_assoc_list, 0, 0);
 				list_destroy(temp_assoc_list);
 				notice_thread_init();
 
