@@ -465,6 +465,16 @@ _process_command (int argc, char *argv[])
 				 argv[0]);
 		}
 		readonly_flag = 1;
+	} else if (strncasecmp (argv[0], "reconfigure",
+				MAX(command_len, 4)) == 0) {
+		if (argc > 1) {
+			exit_code = 1;
+			fprintf (stderr,
+				 "too many arguments for %s keyword\n",
+				 argv[0]);
+		}
+
+		slurmdb_reconfig(db_conn);
 	} else if (strncasecmp (argv[0], "rollup", MAX(command_len, 2)) == 0) {
 		time_t my_start = 0;
 		time_t my_end = 0;
@@ -828,6 +838,7 @@ sacctmgr [<OPTION>] [<COMMAND>]                                            \n\
      quiet                    print no messages other than error messages. \n\
      quit                     terminate this command.                      \n\
      readonly                 makes it so no modification can happen.      \n\
+     reconfigure              reread the slurmdbd.conf on the DBD.         \n\
      show                     same as list                                 \n\
      verbose                  enable detailed logging.                     \n\
      version                  display tool version number.                 \n\
@@ -913,10 +924,11 @@ sacctmgr [<OPTION>] [<COMMAND>]                                            \n\
                             and PreemptMode=                               \n\
        delete qos         - Descriptions=, ID=, Names=, and PreemptMode=   \n\
                                                                            \n\
-       list resource      - Clusters=, Format=, Manager=, Names=,          \n\
-                            and Servers=                                   \n\
+       list resource      - Clusters=, Descriptions=, Flags=, Format=, Ids=,\n\
+                            Names=, PercentAllowed=, ServerType=, Servers=,\n\
+                            and WithClusters                               \n\
        add resource       - Clusters=, Count=, Descriptions=, Flags=,      \n\
-                            Manager=, Names=, PercentAllowed=, Server=,    \n\
+                            ServerType=, Names=, PercentAllowed=, Server=, \n\
                             and Type=                                      \n\
        modify resource    - (set options) Count=, Flags=, Manager=,        \n\
                             PercentAllowed=,                               \n\
@@ -961,8 +973,7 @@ sacctmgr [<OPTION>] [<COMMAND>]                                            \n\
   One can get an number of characters by following the field option with   \n\
   a %%NUMBER option.  i.e. format=name%%30 will print 30 chars of field name.\n\
                                                                            \n\
-       Account            - Account, CoordinatorList, Description,         \n\
-                            Organization                                   \n\
+       Account            - Account, Coordinators, Description, Organization\n\
                                                                            \n\
        Association        - Account, Cluster, DefaultQOS, Fairshare,       \n\
                             GrpCPUMins, GrpCPURunMins, GrpCPUs, GrpJobs,   \n\
@@ -998,7 +1009,7 @@ sacctmgr [<OPTION>] [<COMMAND>]                                            \n\
                                                                            \n\
        Transactions       - Action, Actor, Info, TimeStamp, Where          \n\
                                                                            \n\
-       User               - AdminLevel, CoordinatorList, DefaultAccount,   \n\
+       User               - AdminLevel, Coordinators, DefaultAccount,      \n\
                             DefaultWCKey, User                             \n\
                                                                            \n\
        WCKey              - Cluster, ID, Name, User                        \n\
