@@ -41,6 +41,7 @@
 #include <fcntl.h>
 
 #include "scontrol.h"
+#include "src/common/bitstring.h"
 #include "src/common/stepd_api.h"
 #include "src/plugins/select/bluegene/bg_enums.h"
 
@@ -275,6 +276,26 @@ scontrol_get_job_state(uint32_t job_id)
 	return (uint16_t) NO_VAL;
 }
 
+static bool _task_id_in_job(job_info_t *job_ptr, uint32_t array_id)
+{
+	bitstr_t *array_bitmap;
+	uint32_t array_len;
+
+	if ((array_id == NO_VAL) ||
+	    (array_id == job_ptr->array_task_id))
+		return true;
+
+	array_bitmap = (bitstr_t *) job_ptr->array_bitmap;
+	if (array_bitmap == NULL)
+		return false;
+	array_len = bit_size(array_bitmap);
+	if (array_id >= array_len)
+		return false;
+	if (bit_test(array_bitmap, array_id))
+		return true;
+	return false;
+}
+
 /*
  * scontrol_print_job - print the specified job's information
  * IN job_id - job's id or NULL to print information about all jobs
@@ -312,10 +333,21 @@ scontrol_print_job (char * job_id_str)
 
 	for (i = 0, job_ptr = job_buffer_ptr->job_array;
 	     i < job_buffer_ptr->record_count; i++, job_ptr++) {
-		if ((array_id != NO_VAL) &&
-		    (array_id != job_ptr->array_task_id))
+		char *save_array_str = NULL;
+		uint32_t save_task_id = 0;
+		if (!_task_id_in_job(job_ptr, array_id))
 			continue;
+		if ((array_id != NO_VAL) && job_ptr->array_task_str) {
+			save_array_str = job_ptr->array_task_str;
+			job_ptr->array_task_str = NULL;
+			save_task_id = job_ptr->array_task_id;
+			job_ptr->array_task_id = array_id;
+		}
 		slurm_print_job_info(stdout, job_ptr, one_liner);
+		if (save_array_str) {
+			job_ptr->array_task_str = save_array_str;
+			job_ptr->array_task_id = save_task_id;
+		}
 		print_cnt++;
 	}
 
@@ -516,8 +548,9 @@ _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 	uint32_t count = 0;
 	uint32_t tcount = 0;
 	int i;
+	uint16_t protocol_version;
 
-	fd = stepd_connect(NULL, node_name, jobid, stepid);
+	fd = stepd_connect(NULL, node_name, jobid, stepid, &protocol_version);
 	if (fd == -1) {
 		exit_code = 1;
 		if (errno == ENOENT) {
@@ -531,7 +564,7 @@ _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 		return;
 	}
 
-	stepd_task_info(fd, &task_info, &tcount);
+	stepd_task_info(fd, protocol_version, &task_info, &tcount);
 	for (i = 0; i < (int)tcount; i++) {
 		if (!task_info[i].exited) {
 			if (stepid == NO_VAL)
@@ -551,7 +584,7 @@ _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 		}
 	}
 
-	stepd_list_pids(fd, &pids, &count);
+	stepd_list_pids(fd, protocol_version, &pids, &count);
 	for (i = 0; i < count; i++) {
 		if (!_in_task_array((pid_t)pids[i], task_info, tcount)) {
 			if (stepid == NO_VAL)
@@ -563,7 +596,6 @@ _list_pids_one_step(const char *node_name, uint32_t jobid, uint32_t stepid)
 		}
 	}
 
-
 	if (count > 0)
 		xfree(pids);
 	if (tcount > 0)
