@@ -152,9 +152,9 @@ extern void	scontrol_print_block (char *block_name);
 extern void	scontrol_print_res (char *reservation_name);
 extern void	scontrol_print_step (char *job_step_id_str);
 extern void	scontrol_print_topo (char *node_list);
-extern int	scontrol_requeue(int argc, char **argv);
-extern int	scontrol_requeue_hold(int argc, char **argv);
-extern int	scontrol_suspend(char *op, char *job_id_str);
+extern void	scontrol_requeue(int argc, char **argv);
+extern void	scontrol_requeue_hold(int argc, char **argv);
+extern void	scontrol_suspend(char *op, char *job_id_str);
 extern int	scontrol_update_front_end (int argc, char *argv[]);
 extern int	scontrol_update_job (int argc, char *argv[]);
 extern int	scontrol_update_node (int argc, char *argv[]);
