@@ -69,6 +69,7 @@
 /* FUNCTIONS */
 static List  _build_state_list( char* str );
 static List  _build_all_states_list( void );
+static List  _build_part_list( char *parts );
 static char *_get_prefix(char *token);
 static void  _help( void );
 static int   _parse_format( char* );
@@ -89,6 +90,8 @@ extern void parse_command_line(int argc, char *argv[])
 	int opt_char;
 	int option_index;
 	hostlist_t host_list;
+	bool opt_a_set = false, opt_p_set = false;
+	bool env_a_set = false, env_p_set = false;
 	static struct option long_options[] = {
 		{"all",       no_argument,       0, 'a'},
 		{"bg",        no_argument,       0, 'b'},
@@ -117,12 +120,21 @@ extern void parse_command_line(int argc, char *argv[])
 		{NULL,        0,                 0, 0}
 	};
 
-	if (getenv("SINFO_ALL"))
+	if (getenv("SINFO_ALL")) {
+		env_a_set = true;
 		params.all_flag = true;
+	}
 	if ( ( env_val = getenv("SINFO_PARTITION") ) ) {
+		env_p_set = true;
 		params.partition = xstrdup(env_val);
+		params.part_list = _build_part_list(env_val);
 		params.all_flag = true;
 	}
+	if (env_a_set && env_p_set) {
+		error("Conflicting options, SINFO_ALL and SINFO_PARTITION, specified. "
+		      "Please choose one or the other.");
+		exit(1);
+	}
 	if ( ( env_val = getenv("SINFO_SORT") ) )
 		params.sort = xstrdup(env_val);
 	if ( ( env_val = getenv("SLURM_CLUSTERS") ) ) {
@@ -142,6 +154,10 @@ extern void parse_command_line(int argc, char *argv[])
 			exit(1);
 			break;
 		case (int)'a':
+			opt_a_set = true;
+			xfree(params.partition);
+			if (params.partition)
+				list_destroy(params.part_list);
 			params.all_flag = true;
 			break;
 		case (int)'b':
@@ -214,8 +230,12 @@ extern void parse_command_line(int argc, char *argv[])
 			params.format = xstrdup(optarg);
 			break;
 		case (int) 'p':
+			opt_p_set = true;
 			xfree(params.partition);
+			if (params.partition)
+				list_destroy(params.part_list);
 			params.partition = xstrdup(optarg);
+			params.part_list = _build_part_list(optarg);
 			params.all_flag = true;
 			break;
 		case (int) 'r':
@@ -260,6 +280,12 @@ extern void parse_command_line(int argc, char *argv[])
 		}
 	}
 
+	if (opt_a_set && opt_p_set) {
+		error("Conflicting options, -a and -p, specified. "
+		      "Please choose one or the other.");
+		exit(1);
+	}
+
 	params.cluster_flags = slurmdb_setup_cluster_flags();
 
 	if ( params.format == NULL ) {
@@ -394,6 +420,29 @@ _build_all_states_list( void )
 	return my_list;
 }
 
+/*
+ * _build_part_list - build a list of partition names
+ * IN parts - comma separated list of partitions
+ * RET List of partition names
+ */
+static List
+_build_part_list(char *parts)
+{
+	List part_list;
+	char *orig, *str, *part;
+
+	orig = str = xstrdup(parts);
+	part_list = list_create(NULL);
+
+	while ((part = _next_tok (",", &str))) {
+		char *tmp_part = xstrdup(part);
+		list_append (part_list, tmp_part);
+	}
+
+	xfree(orig);
+	return (part_list);
+}
+
 static const char *
 _node_state_list (void)
 {
@@ -403,7 +452,7 @@ _node_state_list (void)
 	if (all_states)
 		return (all_states);
 
-	all_states = xstrdup (node_state_string_compact (0));
+	all_states = xstrdup (node_state_string(0));
 	for (i = 1; i < NODE_STATE_END; i++) {
 		xstrcat (all_states, ",");
 		xstrcat (all_states, node_state_string(i));
@@ -800,7 +849,7 @@ _get_prefix( char *token )
  * OUT field - the letter code for the data type
  * OUT field_size - byte count
  * OUT right_justify - true of field to be right justified
- * OUT suffix - tring containing everthing after the field specification
+ * OUT suffix - string containing everthing after the field specification
  */
 static void
 _parse_token( char *token, char *field, int *field_size, bool *right_justify,
