@@ -74,7 +74,6 @@
 /* Change PART_STATE_VERSION value when changing the state save format */
 #define PART_STATE_VERSION        "PROTOCOL_VERSION"
 #define PART_2_6_STATE_VERSION    "VER004"	/* SLURM version 2.6 */
-#define PART_2_5_STATE_VERSION    "VER003"	/* SLURM version 2.5 */
 
 /* Global variables */
 struct part_record default_part;	/* default configuration values */
@@ -542,8 +541,6 @@ int load_all_part_state(void)
 			safe_unpack16(&protocol_version, buffer);
 		} else if (!strcmp(ver_str, PART_2_6_STATE_VERSION)) {
 			protocol_version = SLURM_2_6_PROTOCOL_VERSION;
-		} else if (!strcmp(ver_str, PART_2_5_STATE_VERSION)) {
-			protocol_version = SLURM_2_5_PROTOCOL_VERSION;
 		}
 	}
 
@@ -623,39 +620,6 @@ int load_all_part_state(void)
 			safe_unpack16(&state_up, buffer);
 			safe_unpack16(&cr_type, buffer);
 
-			safe_unpackstr_xmalloc(&allow_groups,
-					       &name_len, buffer);
-			safe_unpackstr_xmalloc(&allow_alloc_nodes,
-					       &name_len, buffer);
-			safe_unpackstr_xmalloc(&alternate, &name_len, buffer);
-			safe_unpackstr_xmalloc(&nodes, &name_len, buffer);
-			if ((flags & PART_FLAG_DEFAULT_CLR) ||
-			    (flags & PART_FLAG_HIDDEN_CLR)  ||
-			    (flags & PART_FLAG_NO_ROOT_CLR) ||
-			    (flags & PART_FLAG_ROOT_ONLY_CLR) ||
-			    (flags & PART_FLAG_REQ_RESV_CLR)) {
-				error("Invalid data for partition %s: flags=%u",
-				      part_name, flags);
-				error_code = EINVAL;
-			}
-		} else if (protocol_version >= SLURM_2_5_PROTOCOL_VERSION) {
-			safe_unpackstr_xmalloc(&part_name, &name_len, buffer);
-			safe_unpack32(&grace_time, buffer);
-			safe_unpack32(&max_time, buffer);
-			safe_unpack32(&default_time, buffer);
-			safe_unpack32(&max_nodes, buffer);
-			safe_unpack32(&min_nodes, buffer);
-
-			safe_unpack16(&flags,        buffer);
-			safe_unpack16(&max_share,    buffer);
-			safe_unpack16(&preempt_mode, buffer);
-			safe_unpack16(&priority,     buffer);
-
-			if (priority > part_max_priority)
-				part_max_priority = priority;
-			cr_type = 0;	/* Default value */
-
-			safe_unpack16(&state_up, buffer);
 			safe_unpackstr_xmalloc(&allow_groups,
 					       &name_len, buffer);
 			safe_unpackstr_xmalloc(&allow_alloc_nodes,
@@ -1131,35 +1095,6 @@ void pack_part(struct part_record *part_ptr, Buf buffer,
 		pack16(part_ptr->state_up, buffer);
 		pack16(part_ptr->cr_type, buffer);
 
-		packstr(part_ptr->allow_groups, buffer);
-		packstr(part_ptr->allow_alloc_nodes, buffer);
-		packstr(part_ptr->alternate, buffer);
-		packstr(part_ptr->nodes, buffer);
-		pack_bit_fmt(part_ptr->node_bitmap, buffer);
-	} else if (protocol_version >= SLURM_2_5_PROTOCOL_VERSION) {
-		if (default_part_loc == part_ptr)
-			part_ptr->flags |= PART_FLAG_DEFAULT;
-		else
-			part_ptr->flags &= (~PART_FLAG_DEFAULT);
-
-		packstr(part_ptr->name, buffer);
-		pack32(part_ptr->grace_time, buffer);
-		pack32(part_ptr->max_time, buffer);
-		pack32(part_ptr->default_time, buffer);
-		pack32(part_ptr->max_nodes_orig, buffer);
-		pack32(part_ptr->min_nodes_orig, buffer);
-		altered = part_ptr->total_nodes;
-		select_g_alter_node_cnt(SELECT_APPLY_NODE_MAX_OFFSET, &altered);
-		pack32(altered,              buffer);
-		pack32(part_ptr->total_cpus, buffer);
-		pack32(part_ptr->def_mem_per_cpu, buffer);
-		pack32(part_ptr->max_mem_per_cpu, buffer);
-		pack16(part_ptr->flags,      buffer);
-		pack16(part_ptr->max_share,  buffer);
-		pack16(part_ptr->preempt_mode, buffer);
-		pack16(part_ptr->priority,   buffer);
-
-		pack16(part_ptr->state_up, buffer);
 		packstr(part_ptr->allow_groups, buffer);
 		packstr(part_ptr->allow_alloc_nodes, buffer);
 		packstr(part_ptr->alternate, buffer);
