@@ -232,6 +232,9 @@ typedef struct {
 					  * POINTER. */
 	mpmd_set_t     *mpmd_set;	/* MPMD specifications for Cray */
 	uint16_t	job_core_spec;	/* count of specialized cores */
+	int		non_smp;	/* Set if task IDs are not monotonically
+					 * increasing across all nodes, set only
+					 * native Cray systems */
 } stepd_step_rec_t;
 
 
