@@ -122,8 +122,8 @@ static void *_safe_signal_while_allocating(void *in_data)
 
 	destroy_job = 1;
 	if (pending_job_id != 0) {
+		info("Job allocation %u has been revoked", pending_job_id);
 		slurm_complete_job(pending_job_id, NO_VAL);
-		info("Job allocation %u has been revoked.", pending_job_id);
 	}
 
 	return NULL;
@@ -589,6 +589,7 @@ slurmctld_msg_init(void)
 	slurm_addr_t slurm_address;
 	uint16_t port;
 	static slurm_fd_t slurmctld_fd   = (slurm_fd_t) 0;
+	uint16_t *ports;
 
 	if (slurmctld_fd)	/* May set early for queued job allocation */
 		return slurmctld_fd;
@@ -596,10 +597,16 @@ slurmctld_msg_init(void)
 	slurmctld_fd = -1;
 	slurmctld_comm_addr.port = 0;
 
-	if ((slurmctld_fd = slurm_init_msg_engine_port(0)) < 0) {
+	if ((ports = slurm_get_srun_port_range()))
+		slurmctld_fd = slurm_init_msg_engine_ports(ports);
+	else
+		slurmctld_fd = slurm_init_msg_engine_port(0);
+
+	if (slurmctld_fd < 0) {
 		error("slurm_init_msg_engine_port error %m");
 		exit(error_exit);
 	}
+
 	if (slurm_get_stream_addr(slurmctld_fd, &slurm_address) < 0) {
 		error("slurm_get_stream_addr error %m");
 		exit(error_exit);
@@ -646,8 +653,8 @@ job_desc_msg_create_from_opts (void)
 #endif
 
 	j->contiguous     = opt.contiguous;
-	if (opt.core_spec)
-		j->core_spec = opt.core_spec;
+	if (opt.core_spec != (uint16_t) NO_VAL)
+		j->core_spec      = opt.core_spec;
 	j->features       = opt.constraints;
 	if (opt.gres && strcasecmp(opt.gres, "NONE"))
 		j->gres   = opt.gres;
@@ -834,7 +841,7 @@ job_desc_msg_create_from_opts (void)
 		j->spank_job_env_size = opt.spank_job_env_size;
 	}
 
-	return (j);
+	return j;
 }
 
 void
