@@ -106,13 +106,12 @@ static int pty_sigarray[] = { SIGWINCH, 0 };
 /*
  * Prototypes:
  */
-static inline int _estimate_nports(int nclients, int cli_per_port);
-static int        _compute_task_count(allocation_info_t *info);
 static void       _set_ntasks(allocation_info_t *info);
 static srun_job_t *_job_create_structure(allocation_info_t *info);
 static char *     _normalize_hostlist(const char *hostlist);
 static int _become_user(void);
-static int _call_spank_local_user(srun_job_t *job);
+static void _call_spank_fini(void);
+static int  _call_spank_local_user(srun_job_t *job);
 static void _default_sigaction(int sig);
 static long _diff_tv_str(struct timeval *tv1, struct timeval *tv2);
 static void _handle_intr(srun_job_t *job);
@@ -355,7 +354,7 @@ job_step_create_allocation(resource_allocation_response_msg_t *resp)
 
 	if ((opt.distribution == SLURM_DIST_ARBITRARY) &&
 	    (count != opt.ntasks)) {
-		error("You asked for %d tasks but specified %d nodes",
+		error("You asked for %d tasks but hostlist specified %d nodes",
 		      opt.ntasks, count);
 		goto error;
 	}
@@ -432,7 +431,7 @@ extern void init_srun(int ac, char **av,
 
 	/* Be sure to call spank_fini when srun exits.
 	 */
-	if (atexit((void (*) (void)) spank_fini) < 0)
+	if (atexit(_call_spank_fini) < 0)
 		error("Failed to register atexit handler for plugins: %m");
 
 	/* set default options, process commandline arguments, and
@@ -587,13 +586,20 @@ extern void create_srun_job(srun_job_t **p_job, bool *got_alloc,
 		}
 		job = job_create_allocation(resp);
 
-		opt.exclusive = false;	/* not applicable for this step */
 		opt.time_limit = NO_VAL;/* not applicable for step, only job */
 		xfree(opt.constraints);	/* not applicable for this step */
 		if (!opt.job_name_set_cmd && opt.job_name_set_env) {
 			/* use SLURM_JOB_NAME env var */
 			opt.job_name_set_cmd = true;
 		}
+		if ((opt.core_spec_set || opt.exclusive) && opt.cpus_set) {
+			/* Step gets specified CPU count, which may only part
+			 * of the job allocation. */
+			opt.exclusive = true;
+		} else {
+			/* Step gets all CPUs in the job allocation. */
+			opt.exclusive = false;
+		}
 
 		/*
 		 *  Become --uid user
@@ -740,41 +746,27 @@ job_force_termination(srun_job_t *job)
 	kill_sent++;
 }
 
-static inline int
-_estimate_nports(int nclients, int cli_per_port)
-{
-	div_t d;
-	d = div(nclients, cli_per_port);
-	return d.rem > 0 ? d.quot + 1 : d.quot;
-}
-
-static int
-_compute_task_count(allocation_info_t *ainfo)
-{
-	int i, cnt = 0;
-#if defined HAVE_BGQ
-//#if defined HAVE_BGQ && HAVE_BG_FILES
-	/* always return the ntasks here for Q */
-	return opt.ntasks;
-#endif
-	if (opt.cpus_set) {
-		for (i = 0; i < ainfo->num_cpu_groups; i++)
-			cnt += ( ainfo->cpu_count_reps[i] *
-				 (ainfo->cpus_per_node[i]/opt.cpus_per_task));
-	} else if (opt.ntasks_per_node != NO_VAL)
-		cnt = ainfo->nnodes * opt.ntasks_per_node;
-
-	return (cnt < ainfo->nnodes) ? ainfo->nnodes : cnt;
-}
-
 static void
 _set_ntasks(allocation_info_t *ai)
 {
-	if (!opt.ntasks_set) {
-		opt.ntasks = _compute_task_count(ai);
-		if (opt.cpus_set)
-			opt.ntasks_set = true;	/* implicit */
+	int cnt = 0;
+
+	if (opt.ntasks_set)
+		return;
+
+	if (opt.ntasks_per_node != NO_VAL) {
+		cnt = ai->nnodes * opt.ntasks_per_node;
+		opt.ntasks_set = true;	/* implicit */
+	} else if (opt.cpus_set) {
+		int i;
+
+		for (i = 0; i < ai->num_cpu_groups; i++)
+			cnt += (ai->cpu_count_reps[i] *
+				(ai->cpus_per_node[i] / opt.cpus_per_task));
+		opt.ntasks_set = true;	/* implicit */
 	}
+
+	opt.ntasks = (cnt < ai->nnodes) ? ai->nnodes : cnt;
 }
 
 /*
@@ -1253,11 +1245,19 @@ static int _set_rlimit_env(void)
 	return rc;
 }
 
-/* Set SLURM_SUBMIT_DIR and SLURM_SUBMIT_HOST environment variables within
- * current state */
+/* Set SLURM_CLUSTER_NAME< SLURM_SUBMIT_DIR and SLURM_SUBMIT_HOST environment 
+ * variables within current state */
 static void _set_submit_dir_env(void)
 {
 	char buf[MAXPATHLEN + 1], host[256];
+	char *cluster_name;
+
+	cluster_name = slurm_get_cluster_name();
+	if (cluster_name) {
+		if (setenvf(NULL, "SLURM_CLUSTER_NAME", "%s", cluster_name) < 0)
+			error("unable to set SLURM_CLUSTER_NAME in environment");
+		xfree(cluster_name);
+	}
 
 	if ((getcwd(buf, MAXPATHLEN)) == NULL)
 		error("getcwd failed: %m");
@@ -1449,3 +1449,8 @@ static int _validate_relative(resource_allocation_response_msg_t *resp)
 	return 0;
 }
 
+static void _call_spank_fini(void)
+{
+	if (-1 != shepard_fd)
+		spank_fini(NULL);
+}
